@@ -96,10 +96,7 @@ def init_app(app):
 
 
 def _unauthorized():
-    """
-    Indicate that authorization is required.
-    :return:
-    """
+    """Indicate that authorization is required."""
     return Response("Unauthorized", 401, {"WWW-Authenticate": "Negotiate"})
 
 
@@ -147,7 +144,7 @@ def requires_authentication(function: T):
                 response = function(*args, **kwargs)
                 response = make_response(response)
                 if ctx.kerberos_token is not None:
-                    response.headers["WWW-Authenticate"] = " ".join(["negotiate", ctx.kerberos_token])
+                    response.headers["WWW-Authenticate"] = f"negotiate {ctx.kerberos_token}"
 
                 return response
             if return_code != kerberos.AUTH_GSS_CONTINUE:
