@@ -31,7 +31,7 @@ from typing import Any, Callable, Generator, cast
 
 from botocore.exceptions import ClientError
 
-from airflow.exceptions import AirflowException
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
 from airflow.providers.amazon.aws.hooks.logs import AwsLogsHook
 from airflow.providers.amazon.aws.hooks.s3 import S3Hook
@@ -40,8 +40,8 @@ from airflow.utils import timezone
 
 
 class LogState:
-    """
-    Enum-style class holding all possible states of CloudWatch log streams.
+    """Enum-style class holding all possible states of CloudWatch log streams.
+
     https://sagemaker.readthedocs.io/en/stable/session.html#sagemaker.session.LogState
     """
 
@@ -58,7 +58,10 @@ Position = collections.namedtuple("Position", ["timestamp", "skip"])
 
 
 def argmin(arr, f: Callable) -> int | None:
-    """Return the index, i, in arr that minimizes f(arr[i])"""
+    """Given callable ``f``, find index in ``arr`` to minimize ``f(arr[i])``.
+
+    None is returned if ``arr`` is empty.
+    """
     min_value = None
     min_idx = None
     for idx, item in enumerate(arr):
@@ -70,8 +73,7 @@ def argmin(arr, f: Callable) -> int | None:
 
 
 def secondary_training_status_changed(current_job_description: dict, prev_job_description: dict) -> bool:
-    """
-    Returns true if training job's secondary status message has changed.
+    """Check if training job's secondary status message has changed.
 
     :param current_job_description: Current job description, returned from DescribeTrainingJob call.
     :param prev_job_description: Previous job description, returned from DescribeTrainingJob call.
@@ -101,8 +103,7 @@ def secondary_training_status_changed(current_job_description: dict, prev_job_de
 def secondary_training_status_message(
     job_description: dict[str, list[Any]], prev_description: dict | None
 ) -> str:
-    """
-    Returns a string contains start time and the secondary training job status message.
+    """Format string containing start time and the secondary training job status message.
 
     :param job_description: Returned response from DescribeTrainingJob call
     :param prev_description: Previous job description from DescribeTrainingJob call
@@ -127,18 +128,17 @@ def secondary_training_status_message(
     status_strs = []
     for transition in transitions_to_print:
         message = transition["StatusMessage"]
-        time_str = timezone.convert_to_utc(cast(datetime, job_description["LastModifiedTime"])).strftime(
-            "%Y-%m-%d %H:%M:%S"
-        )
-        status_strs.append(f"{time_str} {transition['Status']} - {message}")
+        time_utc = timezone.convert_to_utc(cast(datetime, job_description["LastModifiedTime"]))
+        status_strs.append(f"{time_utc:%Y-%m-%d %H:%M:%S} {transition['Status']} - {message}")
 
     return "\n".join(status_strs)
 
 
 class SageMakerHook(AwsBaseHook):
-    """
-    Interact with Amazon SageMaker.
-    Provide thick wrapper around :external+boto3:py:class:`boto3.client("sagemaker") <SageMaker.Client>`.
+    """Interact with Amazon SageMaker.
+
+    Provide thick wrapper around
+    :external+boto3:py:class:`boto3.client("sagemaker") <SageMaker.Client>`.
 
     Additional arguments (such as ``aws_conn_id``) may be specified and
     are passed down to the underlying AwsBaseHook.
@@ -158,13 +158,11 @@ class SageMakerHook(AwsBaseHook):
         self.logs_hook = AwsLogsHook(aws_conn_id=self.aws_conn_id)
 
     def tar_and_s3_upload(self, path: str, key: str, bucket: str) -> None:
-        """
-        Tar the local file or directory and upload to s3
+        """Tar the local file or directory and upload to s3.
 
         :param path: local file or directory
         :param key: s3 key
         :param bucket: s3 bucket
-        :return: None
         """
         with tempfile.TemporaryFile() as temp_file:
             if os.path.isdir(path):
@@ -178,8 +176,7 @@ class SageMakerHook(AwsBaseHook):
             self.s3_hook.load_file_obj(temp_file, key, bucket, replace=True)
 
     def configure_s3_resources(self, config: dict) -> None:
-        """
-        Extract the S3 operations from the configuration and execute them.
+        """Extract the S3 operations from the configuration and execute them.
 
         :param config: config of SageMaker operation
         """
@@ -197,8 +194,7 @@ class SageMakerHook(AwsBaseHook):
                     self.s3_hook.load_file(op["Path"], op["Key"], op["Bucket"])
 
     def check_s3_url(self, s3url: str) -> bool:
-        """
-        Check if an S3 URL exists
+        """Check if an S3 URL exists.
 
         :param s3url: S3 url
         """
@@ -219,11 +215,9 @@ class SageMakerHook(AwsBaseHook):
         return True
 
     def check_training_config(self, training_config: dict) -> None:
-        """
-        Check if a training configuration is valid
+        """Check if a training configuration is valid.
 
         :param training_config: training_config
-        :return: None
         """
         if "InputDataConfig" in training_config:
             for channel in training_config["InputDataConfig"]:
@@ -231,19 +225,18 @@ class SageMakerHook(AwsBaseHook):
                     self.check_s3_url(channel["DataSource"]["S3DataSource"]["S3Uri"])
 
     def check_tuning_config(self, tuning_config: dict) -> None:
-        """
-        Check if a tuning configuration is valid
+        """Check if a tuning configuration is valid.
 
         :param tuning_config: tuning_config
-        :return: None
         """
         for channel in tuning_config["TrainingJobDefinition"]["InputDataConfig"]:
             if "S3DataSource" in channel["DataSource"]:
                 self.check_s3_url(channel["DataSource"]["S3DataSource"]["S3Uri"])
 
     def multi_stream_iter(self, log_group: str, streams: list, positions=None) -> Generator:
-        """
-        Iterate over the available events coming from a set of log streams in a single log group
+        """Iterate over the available events.
+
+        The events coming from a set of log streams in a single log group
         interleaving the events from each stream so they're yielded in timestamp order.
 
         :param log_group: The name of the log group.
@@ -284,9 +277,10 @@ class SageMakerHook(AwsBaseHook):
         check_interval: int = 30,
         max_ingestion_time: int | None = None,
     ):
-        """
-        Starts a model training job. After training completes, Amazon SageMaker saves
-        the resulting model artifacts to an Amazon S3 location that you specify.
+        """Start a model training job.
+
+        After training completes, Amazon SageMaker saves the resulting model
+        artifacts to an Amazon S3 location that you specify.
 
         :param config: the config for training
         :param wait_for_completion: if the program should keep running until job finishes
@@ -332,12 +326,13 @@ class SageMakerHook(AwsBaseHook):
         check_interval: int = 30,
         max_ingestion_time: int | None = None,
     ):
-        """
-        Starts a hyperparameter tuning job. A hyperparameter tuning job finds the
-        best version of a model by running many training jobs on your dataset using
-        the algorithm you choose and values for hyperparameters within ranges that
-        you specify. It then chooses the hyperparameter values that result in a model
-        that performs the best, as measured by an objective metric that you choose.
+        """Start a hyperparameter tuning job.
+
+        A hyperparameter tuning job finds the best version of a model by running
+        many training jobs on your dataset using the algorithm you choose and
+        values for hyperparameters within ranges that you specify. It then
+        chooses the hyperparameter values that result in a model that performs
+        the best, as measured by an objective metric that you choose.
 
         :param config: the config for tuning
         :param wait_for_completion: if the program should keep running until job finishes
@@ -368,9 +363,10 @@ class SageMakerHook(AwsBaseHook):
         check_interval: int = 30,
         max_ingestion_time: int | None = None,
     ):
-        """
-        Starts a transform job. A transform job uses a trained model to get inferences
-        on a dataset and saves these results to an Amazon S3 location that you specify.
+        """Start a transform job.
+
+        A transform job uses a trained model to get inferences on a dataset and
+        saves these results to an Amazon S3 location that you specify.
 
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.create_transform_job`
@@ -405,11 +401,12 @@ class SageMakerHook(AwsBaseHook):
         check_interval: int = 30,
         max_ingestion_time: int | None = None,
     ):
-        """
-        Use Amazon SageMaker Processing to analyze data and evaluate machine learning
-        models on Amazon SageMaker. With Processing, you can use a simplified, managed
-        experience on SageMaker to run your data processing workloads, such as feature
-        engineering, data validation, model evaluation, and model interpretation.
+        """Use Amazon SageMaker Processing to analyze data and evaluate models.
+
+        With Processing, you can use a simplified, managed experience on
+        SageMaker to run your data processing workloads, such as feature
+        engineering, data validation, model evaluation, and model
+        interpretation.
 
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.create_processing_job`
@@ -435,11 +432,13 @@ class SageMakerHook(AwsBaseHook):
         return response
 
     def create_model(self, config: dict):
-        """
-        Creates a model in Amazon SageMaker. In the request, you name the model and
-        describe a primary container. For the primary container, you specify the Docker
-        image that contains inference code, artifacts (from prior training), and a custom
-        environment map that the inference code uses when you deploy the model for predictions.
+        """Create a model in Amazon SageMaker.
+
+        In the request, you name the model and describe a primary container. For
+        the primary container, you specify the Docker image that contains
+        inference code, artifacts (from prior training), and a custom
+        environment map that the inference code uses when you deploy the model
+        for predictions.
 
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.create_model`
@@ -450,11 +449,11 @@ class SageMakerHook(AwsBaseHook):
         return self.get_conn().create_model(**config)
 
     def create_endpoint_config(self, config: dict):
-        """
-        Creates an endpoint configuration that Amazon SageMaker hosting
-        services uses to deploy models. In the configuration, you identify
-        one or more models, created using the CreateModel API, to deploy and
-        the resources that you want Amazon SageMaker to provision.
+        """Create an endpoint configuration to deploy models.
+
+        In the configuration, you identify one or more models, created using the
+        CreateModel API, to deploy and the resources that you want Amazon
+        SageMaker to provision.
 
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.create_endpoint_config`
@@ -473,14 +472,13 @@ class SageMakerHook(AwsBaseHook):
         check_interval: int = 30,
         max_ingestion_time: int | None = None,
     ):
-        """
+        """Create an endpoint from configuration.
+
         When you create a serverless endpoint, SageMaker provisions and manages
         the compute resources for you. Then, you can make inference requests to
         the endpoint and receive model predictions in response. SageMaker scales
         the compute resources up and down as needed to handle your request traffic.
 
-        Requires an Endpoint Config.
-
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.create_endpoint`
             - :class:`airflow.providers.amazon.aws.hooks.sagemaker.SageMakerHook.create_endpoint`
@@ -513,10 +511,10 @@ class SageMakerHook(AwsBaseHook):
         check_interval: int = 30,
         max_ingestion_time: int | None = None,
     ):
-        """
-        Deploys the new EndpointConfig specified in the request, switches to using
-        newly created endpoint, and then deletes resources provisioned for the
-        endpoint using the previous EndpointConfig (there is no availability loss).
+        """Deploy the config in the request and switch to using the new endpoint.
+
+        Resources provisioned for the endpoint using the previous EndpointConfig
+        are deleted (there is no availability loss).
 
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.update_endpoint`
@@ -543,8 +541,7 @@ class SageMakerHook(AwsBaseHook):
         return response
 
     def describe_training_job(self, name: str):
-        """
-        Return the training job info associated with the name
+        """Get the training job info associated with the name.
 
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.describe_training_job`
@@ -564,7 +561,7 @@ class SageMakerHook(AwsBaseHook):
         last_description: dict,
         last_describe_job_call: float,
     ):
-        """Return the training job info associated with job_name and print CloudWatch logs"""
+        """Get the associated training job info and print CloudWatch logs."""
         log_group = "/aws/sagemaker/TrainingJobs"
 
         if len(stream_names) < instance_count:
@@ -616,8 +613,7 @@ class SageMakerHook(AwsBaseHook):
         return state, last_description, last_describe_job_call
 
     def describe_tuning_job(self, name: str) -> dict:
-        """
-        Return the tuning job info associated with the name
+        """Get the tuning job info associated with the name.
 
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.describe_hyper_parameter_tuning_job`
@@ -628,8 +624,7 @@ class SageMakerHook(AwsBaseHook):
         return self.get_conn().describe_hyper_parameter_tuning_job(HyperParameterTuningJobName=name)
 
     def describe_model(self, name: str) -> dict:
-        """
-        Return the SageMaker model info associated with the name
+        """Get the SageMaker model info associated with the name.
 
         :param name: the name of the SageMaker model
         :return: A dict contains all the model info
@@ -637,8 +632,7 @@ class SageMakerHook(AwsBaseHook):
         return self.get_conn().describe_model(ModelName=name)
 
     def describe_transform_job(self, name: str) -> dict:
-        """
-        Return the transform job info associated with the name
+        """Get the transform job info associated with the name.
 
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.describe_transform_job`
@@ -649,8 +643,7 @@ class SageMakerHook(AwsBaseHook):
         return self.get_conn().describe_transform_job(TransformJobName=name)
 
     def describe_processing_job(self, name: str) -> dict:
-        """
-        Return the processing job info associated with the name
+        """Get the processing job info associated with the name.
 
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.describe_processing_job`
@@ -661,8 +654,7 @@ class SageMakerHook(AwsBaseHook):
         return self.get_conn().describe_processing_job(ProcessingJobName=name)
 
     def describe_endpoint_config(self, name: str) -> dict:
-        """
-        Return the endpoint config info associated with the name
+        """Get the endpoint config info associated with the name.
 
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.describe_endpoint_config`
@@ -673,8 +665,7 @@ class SageMakerHook(AwsBaseHook):
         return self.get_conn().describe_endpoint_config(EndpointConfigName=name)
 
     def describe_endpoint(self, name: str) -> dict:
-        """
-        Returns the description of an endpoint.
+        """Get the description of an endpoint.
 
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.describe_endpoint`
@@ -693,18 +684,18 @@ class SageMakerHook(AwsBaseHook):
         max_ingestion_time: int | None = None,
         non_terminal_states: set | None = None,
     ) -> dict:
-        """
-        Check status of a SageMaker resource
+        """Check status of a SageMaker resource.
 
-        :param job_name: name of the resource to check status, can be a job but also pipeline for instance.
+        :param job_name: name of the resource to check status, can be a job but
+            also pipeline for instance.
         :param key: the key of the response dict that points to the state
         :param describe_function: the function used to retrieve the status
         :param args: the arguments for the function
         :param check_interval: the time interval in seconds which the operator
             will check the status of any SageMaker resource
         :param max_ingestion_time: the maximum ingestion time in seconds. Any
-            SageMaker resources that run longer than this will fail. Setting this to
-            None implies no timeout for any SageMaker resource.
+            SageMaker resources that run longer than this will fail. Setting
+            this to None implies no timeout for any SageMaker resource.
         :param non_terminal_states: the set of nonterminal states
         :return: response of describe call after resource is done
         """
@@ -747,9 +738,9 @@ class SageMakerHook(AwsBaseHook):
         check_interval: int,
         max_ingestion_time: int | None = None,
     ):
-        """
-        Display the logs for a given training job, optionally tailing them until the
-        job is complete.
+        """Display logs for a given training job.
+
+        Optionally tailing them until the job is complete.
 
         :param job_name: name of the training job to check status and display logs for
         :param non_terminal_states: the set of non_terminal states
@@ -760,7 +751,6 @@ class SageMakerHook(AwsBaseHook):
         :param max_ingestion_time: the maximum ingestion time in seconds. Any
             SageMaker jobs that run longer than this will fail. Setting this to
             None implies no timeout for any SageMaker job.
-        :return: None
         """
         sec = 0
         description = self.describe_training_job(job_name)
@@ -831,10 +821,11 @@ class SageMakerHook(AwsBaseHook):
     def list_training_jobs(
         self, name_contains: str | None = None, max_results: int | None = None, **kwargs
     ) -> list[dict]:
-        """
-        This method wraps boto3's `list_training_jobs`. The training job name and max results are configurable
-        via arguments. Other arguments are not, and should be provided via kwargs. Note boto3 expects these in
-        CamelCase format, for example:
+        """Call boto3's ``list_training_jobs``.
+
+        The training job name and max results are configurable via arguments.
+        Other arguments are not, and should be provided via kwargs. Note that
+        boto3 expects these in CamelCase, for example:
 
         .. code-block:: python
 
@@ -858,11 +849,11 @@ class SageMakerHook(AwsBaseHook):
     def list_transform_jobs(
         self, name_contains: str | None = None, max_results: int | None = None, **kwargs
     ) -> list[dict]:
-        """
-        This method wraps boto3's `list_transform_jobs`.
+        """Call boto3's ``list_transform_jobs``.
+
         The transform job name and max results are configurable via arguments.
-        Other arguments are not, and should be provided via kwargs. Note boto3 expects these in
-        CamelCase format, for example:
+        Other arguments are not, and should be provided via kwargs. Note that
+        boto3 expects these in CamelCase, for example:
 
         .. code-block:: python
 
@@ -871,10 +862,11 @@ class SageMakerHook(AwsBaseHook):
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.list_transform_jobs`
 
-        :param name_contains: (optional) partial name to match
-        :param max_results: (optional) maximum number of results to return. None returns infinite results
-        :param kwargs: (optional) kwargs to boto3's list_transform_jobs method
-        :return: results of the list_transform_jobs request
+        :param name_contains: (optional) partial name to match.
+        :param max_results: (optional) maximum number of results to return.
+            None returns infinite results.
+        :param kwargs: (optional) kwargs to boto3's list_transform_jobs method.
+        :return: results of the list_transform_jobs request.
         """
         config, max_results = self._preprocess_list_request_args(name_contains, max_results, **kwargs)
         list_transform_jobs_request = partial(self.get_conn().list_transform_jobs, **config)
@@ -884,9 +876,10 @@ class SageMakerHook(AwsBaseHook):
         return results
 
     def list_processing_jobs(self, **kwargs) -> list[dict]:
-        """
-        This method wraps boto3's `list_processing_jobs`. All arguments should be provided via kwargs.
-        Note boto3 expects these in CamelCase format, for example:
+        """Call boto3's `list_processing_jobs`.
+
+        All arguments should be provided via kwargs. Note that boto3 expects
+        these in CamelCase, for example:
 
         .. code-block:: python
 
@@ -907,15 +900,17 @@ class SageMakerHook(AwsBaseHook):
     def _preprocess_list_request_args(
         self, name_contains: str | None = None, max_results: int | None = None, **kwargs
     ) -> tuple[dict[str, Any], int | None]:
-        """
-        This method preprocesses the arguments to the boto3's list_* methods.
-        It will turn arguments name_contains and max_results as boto3 compliant CamelCase format.
-        This method also makes sure that these two arguments are only set once.
+        """Preprocess arguments for boto3's ``list_*`` methods.
+
+        It will turn arguments name_contains and max_results as boto3 compliant
+        CamelCase format. This method also makes sure that these two arguments
+        are only set once.
 
         :param name_contains: boto3 function with arguments
         :param max_results: the result key to iterate over
         :param kwargs: (optional) kwargs to boto3's list_* method
-        :return: Tuple with config dict to be passed to boto3's list_* method and max_results parameter
+        :return: Tuple with config dict to be passed to boto3's list_* method
+            and max_results parameter
         """
         config = {}
 
@@ -938,14 +933,16 @@ class SageMakerHook(AwsBaseHook):
     def _list_request(
         self, partial_func: Callable, result_key: str, max_results: int | None = None
     ) -> list[dict]:
-        """
-        All AWS boto3 list_* requests return results in batches (if the key "NextToken" is contained in the
-        result, there are more results to fetch). The default AWS batch size is 10, and configurable up to
-        100. This function iteratively loads all results (or up to a given maximum).
+        """Process a list request to produce results.
 
-        Each boto3 list_* function returns the results in a list with a different name. The key of this
-        structure must be given to iterate over the results, e.g. "TransformJobSummaries" for
-        list_transform_jobs().
+        All AWS boto3 ``list_*`` requests return results in batches, and if the
+        key "NextToken" is contained in the result, there are more results to
+        fetch. The default AWS batch size is 10, and configurable up to 100.
+        This function iteratively loads all results (or up to a given maximum).
+
+        Each boto3 ``list_*`` function returns the results in a list with a
+        different name. The key of this structure must be given to iterate over
+        the results, e.g. "TransformJobSummaries" for ``list_transform_jobs()``.
 
         :param partial_func: boto3 function with arguments
         :param result_key: the result key to iterate over
@@ -977,21 +974,6 @@ class SageMakerHook(AwsBaseHook):
             else:
                 next_token = response["NextToken"]
 
-    def find_processing_job_by_name(self, processing_job_name: str) -> bool:
-        """
-        Query processing job by name
-
-        This method is deprecated.
-        Please use `airflow.providers.amazon.aws.hooks.sagemaker.count_processing_jobs_by_name`.
-        """
-        warnings.warn(
-            "This method is deprecated. "
-            "Please use `airflow.providers.amazon.aws.hooks.sagemaker.count_processing_jobs_by_name`.",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-        return bool(self.count_processing_jobs_by_name(processing_job_name))
-
     @staticmethod
     def _name_matches_pattern(
         processing_job_name: str,
@@ -1008,8 +990,8 @@ class SageMakerHook(AwsBaseHook):
         throttle_retry_delay: int = 2,
         retries: int = 3,
     ) -> int:
-        """
-        Returns the number of processing jobs found with the provided name prefix.
+        """Get the number of processing jobs found with the provided name prefix.
+
         :param processing_job_name: The prefix to look for.
         :param job_name_suffix: The optional suffix which may be appended to deduplicate an existing job name.
         :param throttle_retry_delay: Seconds to wait if a ThrottlingException is hit.
@@ -1038,8 +1020,7 @@ class SageMakerHook(AwsBaseHook):
             raise
 
     def delete_model(self, model_name: str):
-        """
-        Delete SageMaker model.
+        """Delete a SageMaker model.
 
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.delete_model`
@@ -1053,8 +1034,7 @@ class SageMakerHook(AwsBaseHook):
             raise
 
     def describe_pipeline_exec(self, pipeline_exec_arn: str, verbose: bool = False):
-        """
-        Get info about a SageMaker pipeline execution.
+        """Get info about a SageMaker pipeline execution.
 
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.describe_pipeline_execution`
@@ -1080,11 +1060,10 @@ class SageMakerHook(AwsBaseHook):
         display_name: str = "airflow-triggered-execution",
         pipeline_params: dict | None = None,
         wait_for_completion: bool = False,
-        check_interval: int = 30,
+        check_interval: int | None = None,
         verbose: bool = True,
     ) -> str:
-        """
-        Start a new execution for a SageMaker pipeline.
+        """Start a new execution for a SageMaker pipeline.
 
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.start_pipeline_execution`
@@ -1093,14 +1072,19 @@ class SageMakerHook(AwsBaseHook):
         :param display_name: The name this pipeline execution will have in the UI. Doesn't need to be unique.
         :param pipeline_params: Optional parameters for the pipeline.
             All parameters supplied need to already be present in the pipeline definition.
-        :param wait_for_completion: Will only return once the pipeline is complete if true.
-        :param check_interval: How long to wait between checks for pipeline status when waiting for
-            completion.
-        :param verbose: Whether to print steps details when waiting for completion.
-            Defaults to true, consider turning off for pipelines that have thousands of steps.
 
         :return: the ARN of the pipeline execution launched.
         """
+        if wait_for_completion or check_interval is not None:
+            warnings.warn(
+                "parameter `wait_for_completion` and `check_interval` are deprecated, "
+                "remove them and call check_status yourself if you want to wait for completion",
+                AirflowProviderDeprecationWarning,
+                stacklevel=2,
+            )
+        if check_interval is None:
+            check_interval = 30
+
         formatted_params = format_tags(pipeline_params, key_label="Name")
 
         try:
@@ -1128,23 +1112,17 @@ class SageMakerHook(AwsBaseHook):
         self,
         pipeline_exec_arn: str,
         wait_for_completion: bool = False,
-        check_interval: int = 10,
+        check_interval: int | None = None,
         verbose: bool = True,
         fail_if_not_running: bool = False,
     ) -> str:
-        """Stop SageMaker pipeline execution
+        """Stop SageMaker pipeline execution.
 
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.stop_pipeline_execution`
 
         :param pipeline_exec_arn: Amazon Resource Name (ARN) of the pipeline execution.
             It's the ARN of the pipeline itself followed by "/execution/" and an id.
-        :param wait_for_completion: Whether to wait for the pipeline to reach a final state.
-            (i.e. either 'Stopped' or 'Failed')
-        :param check_interval: How long to wait between checks for pipeline status when waiting for
-            completion.
-        :param verbose: Whether to print steps details when waiting for completion.
-            Defaults to true, consider turning off for pipelines that have thousands of steps.
         :param fail_if_not_running: This method will raise an exception if the pipeline we're trying to stop
             is not in an "Executing" state when the call is sent (which would mean that the pipeline is
             already either stopping or stopped).
@@ -1153,15 +1131,22 @@ class SageMakerHook(AwsBaseHook):
         :return: Status of the pipeline execution after the operation.
             One of 'Executing'|'Stopping'|'Stopped'|'Failed'|'Succeeded'.
         """
-        retries = 2  # i.e. 3 calls max, 1 initial + 2 retries
-        while True:
+        if wait_for_completion or check_interval is not None:
+            warnings.warn(
+                "parameter `wait_for_completion` and `check_interval` are deprecated, "
+                "remove them and call check_status yourself if you want to wait for completion",
+                AirflowProviderDeprecationWarning,
+                stacklevel=2,
+            )
+        if check_interval is None:
+            check_interval = 10
+
+        for retries in (2, 1, 0):
             try:
                 self.conn.stop_pipeline_execution(PipelineExecutionArn=pipeline_exec_arn)
-                break
             except ClientError as ce:
                 # this can happen if the pipeline was transitioning between steps at that moment
-                if ce.response["Error"]["Code"] == "ConflictException" and retries > 0:
-                    retries = retries - 1
+                if ce.response["Error"]["Code"] == "ConflictException" and retries:
                     self.log.warning(
                         "Got a conflict exception when trying to stop the pipeline, "
                         "retrying %s more times. Error was: %s",
@@ -1169,18 +1154,20 @@ class SageMakerHook(AwsBaseHook):
                         ce,
                     )
                     time.sleep(0.3)  # error is due to a race condition, so it should be very transient
-                    continue
-                # we have to rely on the message to catch the right error here, because its type
-                # (ValidationException) is shared with other kinds of errors (e.g. badly formatted ARN)
-                if (
-                    not fail_if_not_running
-                    and "Only pipelines with 'Executing' status can be stopped"
-                    in ce.response["Error"]["Message"]
-                ):
-                    self.log.warning("Cannot stop pipeline execution, as it was not running: %s", ce)
                 else:
-                    self.log.error(ce)
-                    raise
+                    # we have to rely on the message to catch the right error here, because its type
+                    # (ValidationException) is shared with other kinds of errors (e.g. badly formatted ARN)
+                    if (
+                        not fail_if_not_running
+                        and "Only pipelines with 'Executing' status can be stopped"
+                        in ce.response["Error"]["Message"]
+                    ):
+                        self.log.warning("Cannot stop pipeline execution, as it was not running: %s", ce)
+                        break
+                    else:
+                        self.log.error(ce)
+                        raise
+            else:
                 break
 
         res = self.describe_pipeline_exec(pipeline_exec_arn)
@@ -1197,8 +1184,7 @@ class SageMakerHook(AwsBaseHook):
         return res["PipelineExecutionStatus"]
 
     def create_model_package_group(self, package_group_name: str, package_group_desc: str = "") -> bool:
-        """
-        Creates a Model Package Group if it does not already exist
+        """Create a Model Package Group if it does not already exist.
 
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.create_model_package_group`
@@ -1251,9 +1237,10 @@ class SageMakerHook(AwsBaseHook):
         wait_for_completion: bool = True,
         check_interval: int = 30,
     ) -> dict | None:
-        """
-        Creates an auto ML job, learning to predict the given column from the data provided through S3.
-        The learning output is written to the specified S3 location.
+        """Create an auto ML job to predict the given column.
+
+        The learning input is based on data provided through S3 , and the output
+        is written to the specified S3 location.
 
         .. seealso::
             - :external+boto3:py:meth:`SageMaker.Client.create_auto_ml_job`
