@@ -15,12 +15,14 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import TYPE_CHECKING, Any, Optional, Sequence
+from __future__ import annotations
+
+from functools import cached_property
+from typing import TYPE_CHECKING, Any, Sequence
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
-from airflow.compat.functools import cached_property
 from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.hooks.athena import AthenaHook
 from airflow.sensors.base import BaseSensorOperator
@@ -28,8 +30,7 @@ from airflow.sensors.base import BaseSensorOperator
 
 class AthenaSensor(BaseSensorOperator):
     """
-    Asks for the state of the Query until it reaches a failure state or success state.
-    If the query fails, the task will fail.
+    Poll the state of the Query until it reaches a terminal state; fails if the query fails.
 
     .. seealso::
         For more information on how to use this sensor, take a look at the guide:
@@ -45,25 +46,25 @@ class AthenaSensor(BaseSensorOperator):
     """
 
     INTERMEDIATE_STATES = (
-        'QUEUED',
-        'RUNNING',
+        "QUEUED",
+        "RUNNING",
     )
     FAILURE_STATES = (
-        'FAILED',
-        'CANCELLED',
+        "FAILED",
+        "CANCELLED",
     )
-    SUCCESS_STATES = ('SUCCEEDED',)
+    SUCCESS_STATES = ("SUCCEEDED",)
 
-    template_fields: Sequence[str] = ('query_execution_id',)
+    template_fields: Sequence[str] = ("query_execution_id",)
     template_ext: Sequence[str] = ()
-    ui_color = '#66c3ff'
+    ui_color = "#66c3ff"
 
     def __init__(
         self,
         *,
         query_execution_id: str,
-        max_retries: Optional[int] = None,
-        aws_conn_id: str = 'aws_default',
+        max_retries: int | None = None,
+        aws_conn_id: str = "aws_default",
         sleep_time: int = 10,
         **kwargs: Any,
     ) -> None:
@@ -73,11 +74,11 @@ class AthenaSensor(BaseSensorOperator):
         self.sleep_time = sleep_time
         self.max_retries = max_retries
 
-    def poke(self, context: 'Context') -> bool:
-        state = self.hook.poll_query_status(self.query_execution_id, self.max_retries)
+    def poke(self, context: Context) -> bool:
+        state = self.hook.poll_query_status(self.query_execution_id, self.max_retries, self.sleep_time)
 
         if state in self.FAILURE_STATES:
-            raise AirflowException('Athena sensor failed')
+            raise AirflowException("Athena sensor failed")
 
         if state in self.INTERMEDIATE_STATES:
             return False
@@ -85,5 +86,5 @@ class AthenaSensor(BaseSensorOperator):
 
     @cached_property
     def hook(self) -> AthenaHook:
-        """Create and return an AthenaHook"""
-        return AthenaHook(self.aws_conn_id, sleep_time=self.sleep_time)
+        """Create and return an AthenaHook."""
+        return AthenaHook(self.aws_conn_id)
