@@ -17,11 +17,11 @@
 # under the License.
 from __future__ import annotations
 
+from functools import cached_property
 from typing import TYPE_CHECKING, Sequence
 
 from deprecated import deprecated
 
-from airflow.compat.functools import cached_property
 from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.hooks.glue_crawler import GlueCrawlerHook
 from airflow.sensors.base import BaseSensorOperator
@@ -32,7 +32,8 @@ if TYPE_CHECKING:
 
 class GlueCrawlerSensor(BaseSensorOperator):
     """
-    Waits for an AWS Glue crawler to reach any of the statuses below
+    Waits for an AWS Glue crawler to reach any of the statuses below.
+
     'FAILED', 'CANCELLED', 'SUCCEEDED'
 
     .. seealso::
@@ -68,7 +69,7 @@ class GlueCrawlerSensor(BaseSensorOperator):
 
     @deprecated(reason="use `hook` property instead.")
     def get_hook(self) -> GlueCrawlerHook:
-        """Returns a new or pre-existing GlueCrawlerHook"""
+        """Returns a new or pre-existing GlueCrawlerHook."""
         return self.hook
 
     @cached_property
