@@ -15,14 +15,15 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Reads and then deletes the message from SQS queue"""
+"""Reads and then deletes the message from SQS queue."""
 from __future__ import annotations
 
 import json
-from typing import TYPE_CHECKING, Any, Collection, Sequence
+from functools import cached_property
+from typing import TYPE_CHECKING, Any, Collection, Literal, Sequence
 
+from deprecated import deprecated
 from jsonpath_ng import parse
-from typing_extensions import Literal
 
 from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.hooks.base_aws import BaseAwsConnection
@@ -36,6 +37,7 @@ if TYPE_CHECKING:
 class SqsSensor(BaseSensorOperator):
     """
     Get messages from an Amazon SQS queue and then delete the messages from the queue.
+
     If deletion of messages fails, an AirflowException is thrown. Otherwise, the messages
     are pushed through XCom with the key ``messages``.
 
@@ -111,8 +113,6 @@ class SqsSensor(BaseSensorOperator):
 
         self.message_filtering_config = message_filtering_config
 
-        self.hook: SqsHook | None = None
-
     def poll_sqs(self, sqs_conn: BaseAwsConnection) -> Collection:
         """
         Poll SQS queue to retrieve messages.
@@ -152,13 +152,11 @@ class SqsSensor(BaseSensorOperator):
         :param context: the context object
         :return: ``True`` if message is available or ``False``
         """
-        sqs_conn = self.get_hook().get_conn()
-
         message_batch: list[Any] = []
 
         # perform multiple SQS call to retrieve messages in series
         for _ in range(self.num_batches):
-            messages = self.poll_sqs(sqs_conn=sqs_conn)
+            messages = self.poll_sqs(sqs_conn=self.hook.conn)
 
             if not len(messages):
                 continue
@@ -173,26 +171,25 @@ class SqsSensor(BaseSensorOperator):
                     {"Id": message["MessageId"], "ReceiptHandle": message["ReceiptHandle"]}
                     for message in messages
                 ]
-                response = sqs_conn.delete_message_batch(QueueUrl=self.sqs_queue, Entries=entries)
+                response = self.hook.conn.delete_message_batch(QueueUrl=self.sqs_queue, Entries=entries)
 
                 if "Successful" not in response:
-                    raise AirflowException(
-                        "Delete SQS Messages failed " + str(response) + " for messages " + str(messages)
-                    )
+                    raise AirflowException(f"Delete SQS Messages failed {response} for messages {messages}")
         if not len(message_batch):
             return False
 
         context["ti"].xcom_push(key="messages", value=message_batch)
         return True
 
+    @deprecated(reason="use `hook` property instead.")
     def get_hook(self) -> SqsHook:
-        """Create and return an SqsHook"""
-        if self.hook:
-            return self.hook
-
-        self.hook = SqsHook(aws_conn_id=self.aws_conn_id)
+        """Create and return an SqsHook."""
         return self.hook
 
+    @cached_property
+    def hook(self) -> SqsHook:
+        return SqsHook(aws_conn_id=self.aws_conn_id)
+
     def filter_messages(self, messages):
         if self.message_filtering == "literal":
             return self.filter_messages_literal(messages)
