@@ -35,7 +35,7 @@ from airflow.utils.log.logging_mixin import LoggingMixin
 
 
 class BatchState(Enum):
-    """Batch session states"""
+    """Batch session states."""
 
     NOT_STARTED = "not_started"
     STARTING = "starting"
@@ -92,7 +92,7 @@ class LivyHook(HttpHook, LoggingMixin):
 
     def get_conn(self, headers: dict[str, Any] | None = None) -> Any:
         """
-        Returns http session for use with requests
+        Returns http session for use with requests.
 
         :param headers: additional headers to be passed through as a dictionary
         :return: requests session
@@ -111,7 +111,7 @@ class LivyHook(HttpHook, LoggingMixin):
         retry_args: dict[str, Any] | None = None,
     ) -> Any:
         """
-        Wrapper for HttpHook, allows to change method on the same HttpHook
+        Wrapper for HttpHook, allows to change method on the same HttpHook.
 
         :param method: http method
         :param endpoint: endpoint
@@ -146,7 +146,7 @@ class LivyHook(HttpHook, LoggingMixin):
 
     def post_batch(self, *args: Any, **kwargs: Any) -> int:
         """
-        Perform request to submit batch
+        Perform request to submit batch.
 
         :return: batch session id
         """
@@ -173,26 +173,26 @@ class LivyHook(HttpHook, LoggingMixin):
         batch_id = self._parse_post_response(response.json())
         if batch_id is None:
             raise AirflowException("Unable to parse the batch session id")
-        self.log.info("Batch submitted with session id: %d", batch_id)
+        self.log.info("Batch submitted with session id: %s", batch_id)
 
         return batch_id
 
     def get_batch(self, session_id: int | str) -> dict:
         """
-        Fetch info about the specified batch
+        Fetch info about the specified batch.
 
         :param session_id: identifier of the batch sessions
         :return: response body
         """
         self._validate_session_id(session_id)
 
-        self.log.debug("Fetching info for batch session %d", session_id)
+        self.log.debug("Fetching info for batch session %s", session_id)
         response = self.run_method(endpoint=f"/batches/{session_id}", headers=self.extra_headers)
 
         try:
             response.raise_for_status()
         except requests.exceptions.HTTPError as err:
-            self.log.warning("Got status code %d for session %d", err.response.status_code, session_id)
+            self.log.warning("Got status code %d for session %s", err.response.status_code, session_id)
             raise AirflowException(
                 f"Unable to fetch batch with id: {session_id}. Message: {err.response.text}"
             )
@@ -201,7 +201,7 @@ class LivyHook(HttpHook, LoggingMixin):
 
     def get_batch_state(self, session_id: int | str, retry_args: dict[str, Any] | None = None) -> BatchState:
         """
-        Fetch the state of the specified batch
+        Fetch the state of the specified batch.
 
         :param session_id: identifier of the batch sessions
         :param retry_args: Arguments which define the retry behaviour.
@@ -210,7 +210,7 @@ class LivyHook(HttpHook, LoggingMixin):
         """
         self._validate_session_id(session_id)
 
-        self.log.debug("Fetching info for batch session %d", session_id)
+        self.log.debug("Fetching info for batch session %s", session_id)
         response = self.run_method(
             endpoint=f"/batches/{session_id}/state", retry_args=retry_args, headers=self.extra_headers
         )
@@ -218,7 +218,7 @@ class LivyHook(HttpHook, LoggingMixin):
         try:
             response.raise_for_status()
         except requests.exceptions.HTTPError as err:
-            self.log.warning("Got status code %d for session %d", err.response.status_code, session_id)
+            self.log.warning("Got status code %d for session %s", err.response.status_code, session_id)
             raise AirflowException(
                 f"Unable to fetch batch with id: {session_id}. Message: {err.response.text}"
             )
@@ -230,14 +230,14 @@ class LivyHook(HttpHook, LoggingMixin):
 
     def delete_batch(self, session_id: int | str) -> dict:
         """
-        Delete the specified batch
+        Delete the specified batch.
 
         :param session_id: identifier of the batch sessions
         :return: response body
         """
         self._validate_session_id(session_id)
 
-        self.log.info("Deleting batch session %d", session_id)
+        self.log.info("Deleting batch session %s", session_id)
         response = self.run_method(
             method="DELETE", endpoint=f"/batches/{session_id}", headers=self.extra_headers
         )
@@ -245,7 +245,7 @@ class LivyHook(HttpHook, LoggingMixin):
         try:
             response.raise_for_status()
         except requests.exceptions.HTTPError as err:
-            self.log.warning("Got status code %d for session %d", err.response.status_code, session_id)
+            self.log.warning("Got status code %d for session %s", err.response.status_code, session_id)
             raise AirflowException(
                 f"Could not kill the batch with session id: {session_id}. Message: {err.response.text}"
             )
@@ -255,6 +255,7 @@ class LivyHook(HttpHook, LoggingMixin):
     def get_batch_logs(self, session_id: int | str, log_start_position, log_batch_size) -> dict:
         """
         Gets the session logs for a specified batch.
+
         :param session_id: identifier of the batch sessions
         :param log_start_position: Position from where to pull the logs
         :param log_batch_size: Number of lines to pull in one batch
@@ -269,7 +270,7 @@ class LivyHook(HttpHook, LoggingMixin):
         try:
             response.raise_for_status()
         except requests.exceptions.HTTPError as err:
-            self.log.warning("Got status code %d for session %d", err.response.status_code, session_id)
+            self.log.warning("Got status code %d for session %s", err.response.status_code, session_id)
             raise AirflowException(
                 f"Could not fetch the logs for batch with session id: {session_id}. "
                 f"Message: {err.response.text}"
@@ -278,12 +279,12 @@ class LivyHook(HttpHook, LoggingMixin):
 
     def dump_batch_logs(self, session_id: int | str) -> None:
         """
-        Dumps the session logs for a specified batch
+        Dumps the session logs for a specified batch.
 
         :param session_id: identifier of the batch sessions
         :return: response body
         """
-        self.log.info("Fetching the logs for batch session with id: %d", session_id)
+        self.log.info("Fetching the logs for batch session with id: %s", session_id)
         log_start_line = 0
         log_total_lines = 0
         log_batch_size = 100
@@ -300,7 +301,7 @@ class LivyHook(HttpHook, LoggingMixin):
     @staticmethod
     def _validate_session_id(session_id: int | str) -> None:
         """
-        Validate session id is a int
+        Validate session id is a int.
 
         :param session_id: session id
         """
@@ -312,7 +313,7 @@ class LivyHook(HttpHook, LoggingMixin):
     @staticmethod
     def _parse_post_response(response: dict[Any, Any]) -> int | None:
         """
-        Parse batch response for batch id
+        Parse batch response for batch id.
 
         :param response: response body
         :return: session id
@@ -322,7 +323,7 @@ class LivyHook(HttpHook, LoggingMixin):
     @staticmethod
     def _parse_request_response(response: dict[Any, Any], parameter):
         """
-        Parse batch response for batch id
+        Parse batch response for batch id.
 
         :param response: response body
         :return: value of parameter
@@ -454,7 +455,7 @@ class LivyHook(HttpHook, LoggingMixin):
 
 class LivyAsyncHook(HttpAsyncHook, LoggingMixin):
     """
-    Hook for Apache Livy through the REST API asynchronously
+    Hook for Apache Livy through the REST API asynchronously.
 
     :param livy_conn_id: reference to a pre-defined Livy Connection.
     :param extra_options: A dictionary of options passed to Livy.
@@ -497,7 +498,7 @@ class LivyAsyncHook(HttpAsyncHook, LoggingMixin):
         extra_options: dict[str, Any] | None = None,
     ) -> Any:
         """
-        Performs an asynchronous HTTP request call
+        Performs an asynchronous HTTP request call.
 
         :param endpoint: the endpoint to be called i.e. resource/v1/query?
         :param data: payload to be uploaded or request parameters
@@ -590,7 +591,7 @@ class LivyAsyncHook(HttpAsyncHook, LoggingMixin):
         headers: dict[str, Any] | None = None,
     ) -> Any:
         """
-        Wrapper for HttpAsyncHook, allows to change method on the same HttpAsyncHook
+        Wrapper for HttpAsyncHook, allows to change method on the same HttpAsyncHook.
 
         :param method: http method
         :param endpoint: endpoint
@@ -617,7 +618,7 @@ class LivyAsyncHook(HttpAsyncHook, LoggingMixin):
         :return: batch state
         """
         self._validate_session_id(session_id)
-        self.log.info("Fetching info for batch session %d", session_id)
+        self.log.info("Fetching info for batch session %s", session_id)
         result = await self.run_method(endpoint=f"/batches/{session_id}/state")
         if result["status"] == "error":
             self.log.info(result)
@@ -661,12 +662,12 @@ class LivyAsyncHook(HttpAsyncHook, LoggingMixin):
 
     async def dump_batch_logs(self, session_id: int | str) -> Any:
         """
-        Dumps the session logs for a specified batch asynchronously
+        Dumps the session logs for a specified batch asynchronously.
 
         :param session_id: identifier of the batch sessions
         :return: response body
         """
-        self.log.info("Fetching the logs for batch session with id: %d", session_id)
+        self.log.info("Fetching the logs for batch session with id: %s", session_id)
         log_start_line = 0
         log_total_lines = 0
         log_batch_size = 100
@@ -687,7 +688,7 @@ class LivyAsyncHook(HttpAsyncHook, LoggingMixin):
     @staticmethod
     def _validate_session_id(session_id: int | str) -> None:
         """
-        Validate session id is a int
+        Validate session id is a int.
 
         :param session_id: session id
         """
@@ -699,7 +700,7 @@ class LivyAsyncHook(HttpAsyncHook, LoggingMixin):
     @staticmethod
     def _parse_post_response(response: dict[Any, Any]) -> Any:
         """
-        Parse batch response for batch id
+        Parse batch response for batch id.
 
         :param response: response body
         :return: session id
@@ -709,7 +710,7 @@ class LivyAsyncHook(HttpAsyncHook, LoggingMixin):
     @staticmethod
     def _parse_request_response(response: dict[Any, Any], parameter: Any) -> Any:
         """
-        Parse batch response for batch id
+        Parse batch response for batch id.
 
         :param response: response body
         :return: value of parameter
