@@ -14,9 +14,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Executes task in a Kubernetes POD"""
-
-from typing import List
+"""Executes task in a Kubernetes POD."""
+from __future__ import annotations
 
 from kubernetes.client import ApiClient, models as k8s
 
@@ -44,55 +43,33 @@ def _convert_from_dict(obj, new_class):
 
 
 def convert_volume(volume) -> k8s.V1Volume:
-    """
-    Converts an airflow Volume object into a k8s.V1Volume
+    """Converts an airflow Volume object into a k8s.V1Volume.
 
     :param volume:
-    :return: k8s.V1Volume
     """
     return _convert_kube_model_object(volume, k8s.V1Volume)
 
 
 def convert_volume_mount(volume_mount) -> k8s.V1VolumeMount:
-    """
-    Converts an airflow VolumeMount object into a k8s.V1VolumeMount
+    """Converts an airflow VolumeMount object into a k8s.V1VolumeMount.
 
     :param volume_mount:
-    :return: k8s.V1VolumeMount
     """
     return _convert_kube_model_object(volume_mount, k8s.V1VolumeMount)
 
 
-def convert_resources(resources) -> k8s.V1ResourceRequirements:
-    """
-    Converts an airflow Resources object into a k8s.V1ResourceRequirements
-
-    :param resources:
-    :return: k8s.V1ResourceRequirements
-    """
-    if isinstance(resources, dict):
-        from airflow.providers.cncf.kubernetes.backcompat.pod import Resources
-
-        resources = Resources(**resources)
-    return _convert_kube_model_object(resources, k8s.V1ResourceRequirements)
-
-
 def convert_port(port) -> k8s.V1ContainerPort:
-    """
-    Converts an airflow Port object into a k8s.V1ContainerPort
+    """Converts an airflow Port object into a k8s.V1ContainerPort.
 
     :param port:
-    :return: k8s.V1ContainerPort
     """
     return _convert_kube_model_object(port, k8s.V1ContainerPort)
 
 
-def convert_env_vars(env_vars) -> List[k8s.V1EnvVar]:
-    """
-    Converts a dictionary into a list of env_vars
+def convert_env_vars(env_vars) -> list[k8s.V1EnvVar]:
+    """Converts a dictionary into a list of env_vars.
 
     :param env_vars:
-    :return:
     """
     if isinstance(env_vars, dict):
         res = []
@@ -106,21 +83,17 @@ def convert_env_vars(env_vars) -> List[k8s.V1EnvVar]:
 
 
 def convert_pod_runtime_info_env(pod_runtime_info_envs) -> k8s.V1EnvVar:
-    """
-    Converts a PodRuntimeInfoEnv into an k8s.V1EnvVar
+    """Converts a PodRuntimeInfoEnv into an k8s.V1EnvVar.
 
     :param pod_runtime_info_envs:
-    :return:
     """
     return _convert_kube_model_object(pod_runtime_info_envs, k8s.V1EnvVar)
 
 
-def convert_image_pull_secrets(image_pull_secrets) -> List[k8s.V1LocalObjectReference]:
-    """
-    Converts a PodRuntimeInfoEnv into an k8s.V1EnvVar
+def convert_image_pull_secrets(image_pull_secrets) -> list[k8s.V1LocalObjectReference]:
+    """Converts a PodRuntimeInfoEnv into an k8s.V1EnvVar.
 
     :param image_pull_secrets:
-    :return:
     """
     if isinstance(image_pull_secrets, str):
         secrets = image_pull_secrets.split(",")
@@ -130,20 +103,18 @@ def convert_image_pull_secrets(image_pull_secrets) -> List[k8s.V1LocalObjectRefe
 
 
 def convert_configmap(configmaps) -> k8s.V1EnvFromSource:
-    """
-    Converts a str into an k8s.V1EnvFromSource
+    """Converts a str into an k8s.V1EnvFromSource.
 
     :param configmaps:
-    :return:
     """
     return k8s.V1EnvFromSource(config_map_ref=k8s.V1ConfigMapEnvSource(name=configmaps))
 
 
 def convert_affinity(affinity) -> k8s.V1Affinity:
-    """Converts a dict into an k8s.V1Affinity"""
+    """Converts a dict into an k8s.V1Affinity."""
     return _convert_from_dict(affinity, k8s.V1Affinity)
 
 
 def convert_toleration(toleration) -> k8s.V1Toleration:
-    """Converts a dict into an k8s.V1Toleration"""
+    """Converts a dict into an k8s.V1Toleration."""
     return _convert_from_dict(toleration, k8s.V1Toleration)
