@@ -31,11 +31,9 @@ if TYPE_CHECKING:
 
 class DatadogSensor(BaseSensorOperator):
     """
-    A sensor to listen, with a filter, to datadog event streams and determine
-    if some event was emitted.
+    A sensor to listen, with a filter, to datadog event streams and determine if some event was emitted.
 
-    Depends on the datadog API, which has to be deployed on the same server where
-    Airflow runs.
+    Depends on the datadog API, which has to be deployed on the same server where Airflow runs.
 
     :param datadog_conn_id: The connection to datadog, containing metadata for api keys.
     :param from_seconds_ago: POSIX timestamp start (default 3600).
@@ -98,4 +96,4 @@ class DatadogSensor(BaseSensorOperator):
             return self.response_check(response)
 
         # If no check was inserted, assume any event that matched yields true.
-        return len(response) > 0
+        return bool(response)
