@@ -14,7 +14,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Run ephemeral Docker Swarm services"""
+"""Run ephemeral Docker Swarm services."""
 from __future__ import annotations
 
 from typing import TYPE_CHECKING
@@ -32,6 +32,7 @@ if TYPE_CHECKING:
 class DockerSwarmOperator(DockerOperator):
     """
     Execute a command as an ephemeral docker swarm service.
+
     Example use-case - Using Docker Swarm orchestration to make one-time
     scripts highly available.
 
@@ -105,7 +106,6 @@ class DockerSwarmOperator(DockerOperator):
         **kwargs,
     ) -> None:
         super().__init__(image=image, **kwargs)
-
         self.enable_logging = enable_logging
         self.service = None
         self.configs = configs
@@ -115,16 +115,11 @@ class DockerSwarmOperator(DockerOperator):
         self.placement = placement
 
     def execute(self, context: Context) -> None:
-        self.cli = self._get_cli()
-
         self.environment["AIRFLOW_TMP_DIR"] = self.tmp_dir
-
         return self._run_service()
 
     def _run_service(self) -> None:
         self.log.info("Starting docker service from image %s", self.image)
-        if not self.cli:
-            raise Exception("The 'cli' should be initialized before!")
         self.service = self.cli.create_service(
             types.TaskTemplate(
                 container_spec=types.ContainerSpec(
@@ -166,15 +161,13 @@ class DockerSwarmOperator(DockerOperator):
         if self.service and self._service_status() != "complete":
             if self.auto_remove == "success":
                 self.cli.remove_service(self.service["ID"])
-            raise AirflowException("Service did not complete: " + repr(self.service))
+            raise AirflowException(f"Service did not complete: {self.service!r}")
         elif self.auto_remove == "success":
             if not self.service:
                 raise Exception("The 'service' should be initialized before!")
             self.cli.remove_service(self.service["ID"])
 
     def _service_status(self) -> str | None:
-        if not self.cli:
-            raise Exception("The 'cli' should be initialized before!")
         if not self.service:
             raise Exception("The 'service' should be initialized before!")
         return self.cli.tasks(filters={"service": self.service["ID"]})[0]["Status"]["State"]
@@ -184,8 +177,6 @@ class DockerSwarmOperator(DockerOperator):
         return status in ["complete", "failed", "shutdown", "rejected", "orphaned", "remove"]
 
     def _stream_logs_to_output(self) -> None:
-        if not self.cli:
-            raise Exception("The 'cli' should be initialized before!")
         if not self.service:
             raise Exception("The 'service' should be initialized before!")
         logs = self.cli.service_logs(
@@ -213,6 +204,6 @@ class DockerSwarmOperator(DockerOperator):
             self.log.info(line)
 
     def on_kill(self) -> None:
-        if self.cli is not None and self.service is not None:
+        if self.hook.client_created and self.service is not None:
             self.log.info("Removing docker service: %s", self.service["ID"])
             self.cli.remove_service(self.service["ID"])
