@@ -17,12 +17,12 @@
 from __future__ import annotations
 
 import re
+from functools import cached_property
 
 import google
 from google.api_core.exceptions import InvalidArgument, NotFound, PermissionDenied
 from google.cloud.secretmanager_v1 import SecretManagerServiceClient
 
-from airflow.compat.functools import cached_property
 from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.utils.log.logging_mixin import LoggingMixin
 
@@ -30,11 +30,11 @@ SECRET_ID_PATTERN = r"^[a-zA-Z0-9-_]*$"
 
 
 class _SecretManagerClient(LoggingMixin):
-    """
-    Retrieves Secrets object from Google Cloud Secrets Manager. This is a common class reused between
-    SecretsManager and Secrets Hook that provides the shared authentication and verification mechanisms.
-    This class should not be used directly, use SecretsManager or SecretsHook instead
+    """Retrieve Secrets object from Google Cloud Secrets Manager.
 
+    This is a common class reused between SecretsManager and Secrets Hook that
+    provides the shared authentication and verification mechanisms. This class
+    should not be used directly; use SecretsManager or SecretsHook instead.
 
     :param credentials: Credentials used to authenticate to GCP
     """
@@ -48,22 +48,20 @@ class _SecretManagerClient(LoggingMixin):
 
     @staticmethod
     def is_valid_secret_name(secret_name: str) -> bool:
-        """
-        Returns true if the secret name is valid.
+        """Whether the secret name is valid.
+
         :param secret_name: name of the secret
-        :return:
         """
         return bool(re.match(SECRET_ID_PATTERN, secret_name))
 
     @cached_property
     def client(self) -> SecretManagerServiceClient:
-        """Create an authenticated KMS client"""
+        """Create an authenticated KMS client."""
         _client = SecretManagerServiceClient(credentials=self.credentials, client_info=CLIENT_INFO)
         return _client
 
     def get_secret(self, secret_id: str, project_id: str, secret_version: str = "latest") -> str | None:
-        """
-        Get secret value from the Secret Manager.
+        """Get secret value from the Secret Manager.
 
         :param secret_id: Secret Key
         :param project_id: Project id to use
