@@ -15,7 +15,17 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""This module contains a Google Storage Transfer Service Hook."""
+"""
+This module contains a Google Storage Transfer Service Hook.
+
+.. spelling::
+
+    ListTransferJobsAsyncPager
+    StorageTransferServiceAsyncClient
+
+"""
+
+from __future__ import annotations
 
 import json
 import logging
@@ -23,13 +33,23 @@ import time
 import warnings
 from copy import deepcopy
 from datetime import timedelta
-from typing import List, Optional, Sequence, Set, Union
+from typing import Any, Sequence
 
+from google.cloud.storage_transfer_v1 import (
+    ListTransferJobsRequest,
+    StorageTransferServiceAsyncClient,
+    TransferJob,
+    TransferOperation,
+)
+from google.cloud.storage_transfer_v1.services.storage_transfer_service.pagers import (
+    ListTransferJobsAsyncPager,
+)
 from googleapiclient.discovery import Resource, build
 from googleapiclient.errors import HttpError
+from proto import Message
 
-from airflow.exceptions import AirflowException
-from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
+from airflow.providers.google.common.hooks.base_google import GoogleBaseAsyncHook, GoogleBaseHook
 
 log = logging.getLogger(__name__)
 
@@ -38,7 +58,7 @@ TIME_TO_SLEEP_IN_SECONDS = 10
 
 
 class GcpTransferJobsStatus:
-    """Class with Google Cloud Transfer jobs statuses."""
+    """Google Cloud Transfer job status."""
 
     ENABLED = "ENABLED"
     DISABLED = "DISABLED"
@@ -46,7 +66,7 @@ class GcpTransferJobsStatus:
 
 
 class GcpTransferOperationStatus:
-    """Class with Google Cloud Transfer operations statuses."""
+    """Google Cloud Transfer operation status."""
 
     IN_PROGRESS = "IN_PROGRESS"
     PAUSED = "PAUSED"
@@ -59,53 +79,54 @@ class GcpTransferOperationStatus:
 ACCESS_KEY_ID = "accessKeyId"
 ALREADY_EXISTING_IN_SINK = "overwriteObjectsAlreadyExistingInSink"
 AWS_ACCESS_KEY = "awsAccessKey"
-AWS_S3_DATA_SOURCE = 'awsS3DataSource'
-BODY = 'body'
-BUCKET_NAME = 'bucketName'
-COUNTERS = 'counters'
-DAY = 'day'
+AWS_SECRET_ACCESS_KEY = "secretAccessKey"
+AWS_S3_DATA_SOURCE = "awsS3DataSource"
+BODY = "body"
+BUCKET_NAME = "bucketName"
+COUNTERS = "counters"
+DAY = "day"
 DESCRIPTION = "description"
-FILTER = 'filter'
-FILTER_JOB_NAMES = 'job_names'
-FILTER_PROJECT_ID = 'project_id'
-GCS_DATA_SINK = 'gcsDataSink'
-GCS_DATA_SOURCE = 'gcsDataSource'
+FILTER = "filter"
+FILTER_JOB_NAMES = "job_names"
+FILTER_PROJECT_ID = "project_id"
+GCS_DATA_SINK = "gcsDataSink"
+GCS_DATA_SOURCE = "gcsDataSource"
 HOURS = "hours"
-HTTP_DATA_SOURCE = 'httpDataSource'
-JOB_NAME = 'name'
-LIST_URL = 'list_url'
-METADATA = 'metadata'
+HTTP_DATA_SOURCE = "httpDataSource"
+INCLUDE_PREFIXES = "includePrefixes"
+JOB_NAME = "name"
+LIST_URL = "list_url"
+METADATA = "metadata"
 MINUTES = "minutes"
-MONTH = 'month'
-NAME = 'name'
-OBJECT_CONDITIONS = 'object_conditions'
-OPERATIONS = 'operations'
-PATH = 'path'
-PROJECT_ID = 'projectId'
-SCHEDULE = 'schedule'
-SCHEDULE_END_DATE = 'scheduleEndDate'
-SCHEDULE_START_DATE = 'scheduleStartDate'
+MONTH = "month"
+NAME = "name"
+OBJECT_CONDITIONS = "object_conditions"
+OPERATIONS = "operations"
+OVERWRITE_OBJECTS_ALREADY_EXISTING_IN_SINK = "overwriteObjectsAlreadyExistingInSink"
+PATH = "path"
+PROJECT_ID = "projectId"
+SCHEDULE = "schedule"
+SCHEDULE_END_DATE = "scheduleEndDate"
+SCHEDULE_START_DATE = "scheduleStartDate"
 SECONDS = "seconds"
 SECRET_ACCESS_KEY = "secretAccessKey"
-START_TIME_OF_DAY = 'startTimeOfDay'
+START_TIME_OF_DAY = "startTimeOfDay"
 STATUS = "status"
-STATUS1 = 'status'
-TRANSFER_JOB = 'transfer_job'
-TRANSFER_JOBS = 'transferJobs'
-TRANSFER_JOB_FIELD_MASK = 'update_transfer_job_field_mask'
-TRANSFER_OPERATIONS = 'transferOperations'
-TRANSFER_OPTIONS = 'transfer_options'
-TRANSFER_SPEC = 'transferSpec'
-YEAR = 'year'
+STATUS1 = "status"
+TRANSFER_JOB = "transfer_job"
+TRANSFER_JOBS = "transferJobs"
+TRANSFER_JOB_FIELD_MASK = "update_transfer_job_field_mask"
+TRANSFER_OPERATIONS = "transferOperations"
+TRANSFER_OPTIONS = "transfer_options"
+TRANSFER_SPEC = "transferSpec"
+YEAR = "year"
 ALREADY_EXIST_CODE = 409
 
 NEGATIVE_STATUSES = {GcpTransferOperationStatus.FAILED, GcpTransferOperationStatus.ABORTED}
 
 
 def gen_job_name(job_name: str) -> str:
-    """
-    Adds unique suffix to job name. If suffix already exists, updates it.
-    Suffix — current timestamp
+    """Add a unique suffix to the job name.
 
     :param job_name:
     :return: job_name with suffix
@@ -115,56 +136,55 @@ def gen_job_name(job_name: str) -> str:
 
 
 class CloudDataTransferServiceHook(GoogleBaseHook):
-    """
-    Hook for Google Storage Transfer Service.
+    """Google Storage Transfer Service functionalities.
 
-    All the methods in the hook where project_id is used must be called with
-    keyword arguments rather than positional.
+    All methods in the hook with *project_id* in the signature must be called
+    with keyword arguments rather than positional.
     """
 
     def __init__(
         self,
-        api_version: str = 'v1',
+        api_version: str = "v1",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
+        **kwargs,
     ) -> None:
+        if "delegate_to" in kwargs:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and "
+                "finally removed in this version of Google Provider. You MUST "
+                "convert it to `impersonate_chain`."
+            )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
-            delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
         self.api_version = api_version
         self._conn = None
 
     def get_conn(self) -> Resource:
-        """
-        Retrieves connection to Google Storage Transfer service.
+        """Retrieve connection to Google Storage Transfer service.
 
         :return: Google Storage Transfer service object
-        :rtype: dict
         """
         if not self._conn:
             http_authorized = self._authorize()
             self._conn = build(
-                'storagetransfer', self.api_version, http=http_authorized, cache_discovery=False
+                "storagetransfer", self.api_version, http=http_authorized, cache_discovery=False
             )
         return self._conn
 
     def create_transfer_job(self, body: dict) -> dict:
-        """
-        Creates a transfer job that runs periodically.
+        """Create a transfer job that runs periodically.
 
-        :param body: (Required) A request body, as described in
+        :param body: (Required) The request body, as described in
             https://cloud.google.com/storage-transfer/docs/reference/rest/v1/transferJobs/patch#request-body
-        :return: transfer job.
-            See:
+        :return: The transfer job. See:
             https://cloud.google.com/storage-transfer/docs/reference/rest/v1/transferJobs#TransferJob
-        :rtype: dict
         """
         body = self._inject_project_id(body, BODY, PROJECT_ID)
-        try:
 
+        try:
             transfer_job = (
                 self.get_conn().transferJobs().create(body=body).execute(num_retries=self.num_retries)
             )
@@ -197,16 +217,13 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
 
     @GoogleBaseHook.fallback_to_default_project_id
     def get_transfer_job(self, job_name: str, project_id: str) -> dict:
-        """
-        Gets the latest state of a long-running operation in Google Storage
-        Transfer Service.
+        """Get latest state of a long-running Google Storage Transfer Service job.
 
         :param job_name: (Required) Name of the job to be fetched
         :param project_id: (Optional) the ID of the project that owns the Transfer
             Job. If set to None or missing, the default project_id from the Google Cloud
             connection is used.
         :return: Transfer Job
-        :rtype: dict
         """
         return (
             self.get_conn()
@@ -215,31 +232,30 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
             .execute(num_retries=self.num_retries)
         )
 
-    def list_transfer_job(self, request_filter: Optional[dict] = None, **kwargs) -> List[dict]:
-        """
-        Lists long-running operations in Google Storage Transfer
-        Service that match the specified filter.
+    def list_transfer_job(self, request_filter: dict | None = None, **kwargs) -> list[dict]:
+        """List long-running operations in Google Storage Transfer Service.
+
+        A filter can be specified to match only certain entries.
 
         :param request_filter: (Required) A request filter, as described in
             https://cloud.google.com/storage-transfer/docs/reference/rest/v1/transferJobs/list#body.QUERY_PARAMETERS.filter
         :return: List of Transfer Jobs
-        :rtype: list[dict]
         """
         # To preserve backward compatibility
         # TODO: remove one day
         if request_filter is None:
-            if 'filter' in kwargs:
-                request_filter = kwargs['filter']
+            if "filter" in kwargs:
+                request_filter = kwargs["filter"]
                 if not isinstance(request_filter, dict):
                     raise ValueError(f"The request_filter should be dict and is {type(request_filter)}")
-                warnings.warn("Use 'request_filter' instead of 'filter'", DeprecationWarning)
+                warnings.warn("Use 'request_filter' instead of 'filter'", AirflowProviderDeprecationWarning)
             else:
                 raise TypeError("list_transfer_job missing 1 required positional argument: 'request_filter'")
 
         conn = self.get_conn()
         request_filter = self._inject_project_id(request_filter, FILTER, FILTER_PROJECT_ID)
         request = conn.transferJobs().list(filter=json.dumps(request_filter))
-        jobs: List[dict] = []
+        jobs: list[dict] = []
 
         while request is not None:
             response = request.execute(num_retries=self.num_retries)
@@ -251,15 +267,13 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
 
     @GoogleBaseHook.fallback_to_default_project_id
     def enable_transfer_job(self, job_name: str, project_id: str) -> dict:
-        """
-        New transfers will be performed based on the schedule.
+        """Make new transfers be performed based on the schedule.
 
         :param job_name: (Required) Name of the job to be updated
         :param project_id: (Optional) the ID of the project that owns the Transfer
             Job. If set to None or missing, the default project_id from the Google Cloud
             connection is used.
         :return: If successful, TransferJob.
-        :rtype: dict
         """
         return (
             self.get_conn()
@@ -276,14 +290,12 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         )
 
     def update_transfer_job(self, job_name: str, body: dict) -> dict:
-        """
-        Updates a transfer job that runs periodically.
+        """Update a transfer job that runs periodically.
 
         :param job_name: (Required) Name of the job to be updated
         :param body: A request body, as described in
             https://cloud.google.com/storage-transfer/docs/reference/rest/v1/transferJobs/patch#request-body
         :return: If successful, TransferJob.
-        :rtype: dict
         """
         body = self._inject_project_id(body, BODY, PROJECT_ID)
         return (
@@ -295,17 +307,16 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
 
     @GoogleBaseHook.fallback_to_default_project_id
     def delete_transfer_job(self, job_name: str, project_id: str) -> None:
-        """
-        Deletes a transfer job. This is a soft delete. After a transfer job is
-        deleted, the job and all the transfer executions are subject to garbage
-        collection. Transfer jobs become eligible for garbage collection
-        30 days after soft delete.
+        """Delete a transfer job.
+
+        This is a soft delete. After a transfer job is deleted, the job and all
+        the transfer executions are subject to garbage collection. Transfer jobs
+        become eligible for garbage collection 30 days after soft delete.
 
         :param job_name: (Required) Name of the job to be deleted
         :param project_id: (Optional) the ID of the project that owns the Transfer
             Job. If set to None or missing, the default project_id from the Google Cloud
             connection is used.
-        :rtype: None
         """
         (
             self.get_conn()
@@ -322,23 +333,19 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         )
 
     def cancel_transfer_operation(self, operation_name: str) -> None:
-        """
-        Cancels an transfer operation in Google Storage Transfer Service.
+        """Cancel a transfer operation in Google Storage Transfer Service.
 
         :param operation_name: Name of the transfer operation.
-        :rtype: None
         """
         self.get_conn().transferOperations().cancel(name=operation_name).execute(num_retries=self.num_retries)
 
     def get_transfer_operation(self, operation_name: str) -> dict:
-        """
-        Gets an transfer operation in Google Storage Transfer Service.
+        """Get a transfer operation in Google Storage Transfer Service.
 
         :param operation_name: (Required) Name of the transfer operation.
         :return: transfer operation
-            See:
-            https://cloud.google.com/storage-transfer/docs/reference/rest/v1/Operation
-        :rtype: dict
+
+        .. seealso:: https://cloud.google.com/storage-transfer/docs/reference/rest/v1/Operation
         """
         return (
             self.get_conn()
@@ -347,29 +354,25 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
             .execute(num_retries=self.num_retries)
         )
 
-    def list_transfer_operations(self, request_filter: Optional[dict] = None, **kwargs) -> List[dict]:
-        """
-        Gets an transfer operation in Google Storage Transfer Service.
+    def list_transfer_operations(self, request_filter: dict | None = None, **kwargs) -> list[dict]:
+        """Get a transfer operation in Google Storage Transfer Service.
 
         :param request_filter: (Required) A request filter, as described in
             https://cloud.google.com/storage-transfer/docs/reference/rest/v1/transferJobs/list#body.QUERY_PARAMETERS.filter
             With one additional improvement:
-
-            * project_id is optional if you have a project id defined
-              in the connection
-              See: :doc:`/connections/gcp`
-
         :return: transfer operation
-        :rtype: list[dict]
+
+        The ``project_id`` parameter is optional if you have a project ID
+        defined in the connection. See: :doc:`/connections/gcp`
         """
         # To preserve backward compatibility
         # TODO: remove one day
         if request_filter is None:
-            if 'filter' in kwargs:
-                request_filter = kwargs['filter']
+            if "filter" in kwargs:
+                request_filter = kwargs["filter"]
                 if not isinstance(request_filter, dict):
                     raise ValueError(f"The request_filter should be dict and is {type(request_filter)}")
-                warnings.warn("Use 'request_filter' instead of 'filter'", DeprecationWarning)
+                warnings.warn("Use 'request_filter' instead of 'filter'", AirflowProviderDeprecationWarning)
             else:
                 raise TypeError(
                     "list_transfer_operations missing 1 required positional argument: 'request_filter'"
@@ -379,7 +382,7 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
 
         request_filter = self._inject_project_id(request_filter, FILTER, FILTER_PROJECT_ID)
 
-        operations: List[dict] = []
+        operations: list[dict] = []
 
         request = conn.transferOperations().list(name=TRANSFER_OPERATIONS, filter=json.dumps(request_filter))
 
@@ -395,41 +398,33 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
         return operations
 
     def pause_transfer_operation(self, operation_name: str) -> None:
-        """
-        Pauses an transfer operation in Google Storage Transfer Service.
+        """Pause a transfer operation in Google Storage Transfer Service.
 
         :param operation_name: (Required) Name of the transfer operation.
-        :rtype: None
         """
         self.get_conn().transferOperations().pause(name=operation_name).execute(num_retries=self.num_retries)
 
     def resume_transfer_operation(self, operation_name: str) -> None:
-        """
-        Resumes an transfer operation in Google Storage Transfer Service.
+        """Resume a transfer operation in Google Storage Transfer Service.
 
         :param operation_name: (Required) Name of the transfer operation.
-        :rtype: None
         """
         self.get_conn().transferOperations().resume(name=operation_name).execute(num_retries=self.num_retries)
 
     def wait_for_transfer_job(
         self,
         job: dict,
-        expected_statuses: Optional[Set[str]] = None,
-        timeout: Optional[Union[float, timedelta]] = None,
+        expected_statuses: set[str] | None = None,
+        timeout: float | timedelta | None = None,
     ) -> None:
-        """
-        Waits until the job reaches the expected state.
+        """Wait until the job reaches the expected state.
 
-        :param job: Transfer job
-            See:
+        :param job: The transfer job to wait for. See:
             https://cloud.google.com/storage-transfer/docs/reference/rest/v1/transferJobs#TransferJob
-        :param expected_statuses: State that is expected
-            See:
+        :param expected_statuses: The expected state. See:
             https://cloud.google.com/storage-transfer/docs/reference/rest/v1/transferOperations#Status
-        :param timeout: Time in which the operation must end in seconds. If not specified, defaults to 60
-            seconds.
-        :rtype: None
+        :param timeout: Time in which the operation must end in seconds. If not
+            specified, defaults to 60 seconds.
         """
         expected_statuses = (
             {GcpTransferOperationStatus.SUCCESS} if not expected_statuses else expected_statuses
@@ -464,23 +459,17 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
 
     @staticmethod
     def operations_contain_expected_statuses(
-        operations: List[dict], expected_statuses: Union[Set[str], str]
+        operations: list[dict], expected_statuses: set[str] | str
     ) -> bool:
-        """
-        Checks whether the operation list has an operation with the
-        expected status, then returns true
-        If it encounters operations in FAILED or ABORTED state
-        throw :class:`airflow.exceptions.AirflowException`.
+        """Check whether an operation exists with the expected status.
 
         :param operations: (Required) List of transfer operations to check.
-        :param expected_statuses: (Required) status that is expected
-            See:
+        :param expected_statuses: (Required) The expected status. See:
             https://cloud.google.com/storage-transfer/docs/reference/rest/v1/transferOperations#Status
-        :return: If there is an operation with the expected state
-            in the operation list, returns true,
-        :raises: airflow.exceptions.AirflowException If it encounters operations
-            with a state in the list,
-        :rtype: bool
+        :return: If there is an operation with the expected state in the
+            operation list, returns true,
+        :raises AirflowException: If it encounters operations with state FAILED
+            or ABORTED in the list.
         """
         expected_statuses_set = (
             {expected_statuses} if isinstance(expected_statuses, str) else set(expected_statuses)
@@ -499,3 +488,50 @@ class CloudDataTransferServiceHook(GoogleBaseHook):
                 f"Expected: {', '.join(expected_statuses_set)}"
             )
         return False
+
+
+class CloudDataTransferServiceAsyncHook(GoogleBaseAsyncHook):
+    """Asynchronous hook for Google Storage Transfer Service."""
+
+    def __init__(self, project_id: str | None = None, **kwargs: Any) -> None:
+        super().__init__(**kwargs)
+        self.project_id = project_id
+        self._client: StorageTransferServiceAsyncClient | None = None
+
+    def get_conn(self) -> StorageTransferServiceAsyncClient:
+        """
+        Returns async connection to the Storage Transfer Service.
+
+        :return: Google Storage Transfer asynchronous client.
+        """
+        if not self._client:
+            self._client = StorageTransferServiceAsyncClient()
+        return self._client
+
+    async def get_jobs(self, job_names: list[str]) -> ListTransferJobsAsyncPager:
+        """
+        Gets the latest state of a long-running operations in Google Storage Transfer Service.
+
+        :param job_names: (Required) List of names of the jobs to be fetched.
+        :return: Object that yields Transfer jobs.
+        """
+        client = self.get_conn()
+        jobs_list_request = ListTransferJobsRequest(
+            filter=json.dumps(dict(project_id=self.project_id, job_names=job_names))
+        )
+        return await client.list_transfer_jobs(request=jobs_list_request)
+
+    async def get_latest_operation(self, job: TransferJob) -> Message | None:
+        """
+        Gets the latest operation of the given TransferJob instance.
+
+        :param job: Transfer job instance.
+        :return: The latest job operation.
+        """
+        latest_operation_name = job.latest_operation_name
+        if latest_operation_name:
+            client = self.get_conn()
+            response_operation = await client.transport.operations_client.get_operation(latest_operation_name)
+            operation = TransferOperation.deserialize(response_operation.metadata.value)
+            return operation
+        return None
