@@ -19,7 +19,6 @@ from __future__ import annotations
 
 import json
 import os
-import warnings
 from time import monotonic, sleep
 from typing import Any, Dict, Sequence
 from urllib.parse import quote, urlencode, urljoin
@@ -41,7 +40,7 @@ Operation = Dict[str, Any]
 
 
 class PipelineStates:
-    """Data Fusion pipeline states"""
+    """Data Fusion pipeline states."""
 
     PENDING = "PENDING"
     STARTING = "STARTING"
@@ -67,16 +66,16 @@ class DataFusionHook(GoogleBaseHook):
         self,
         api_version: str = "v1beta1",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
+        **kwargs,
     ) -> None:
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
             )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
-            delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
         self.api_version = api_version
@@ -104,10 +103,7 @@ class DataFusionHook(GoogleBaseHook):
         failure_states: list[str] | None = None,
         timeout: int = 5 * 60,
     ) -> None:
-        """
-        Polls pipeline state and raises an exception if the state is one of
-        `failure_states` or the operation timed_out.
-        """
+        """Polls pipeline state and raises an exception if the state fails or times out."""
         failure_states = failure_states or FAILURE_STATES
         success_states = success_states or SUCCESS_STATES
         start_time = monotonic()
@@ -191,6 +187,7 @@ class DataFusionHook(GoogleBaseHook):
     def restart_instance(self, instance_name: str, location: str, project_id: str) -> Operation:
         """
         Restart a single Data Fusion instance.
+
         At the end of an operation instance is fully restarted.
 
         :param instance_name: The name of the instance to restart.
@@ -322,7 +319,7 @@ class DataFusionHook(GoogleBaseHook):
         namespace: str = "default",
     ) -> None:
         """
-        Creates a Cloud Data Fusion pipeline.
+        Creates a batch Cloud Data Fusion pipeline.
 
         :param pipeline_name: Your pipeline name.
         :param pipeline: The pipeline definition. For more information check:
@@ -346,12 +343,12 @@ class DataFusionHook(GoogleBaseHook):
         namespace: str = "default",
     ) -> None:
         """
-        Deletes a Cloud Data Fusion pipeline.
+        Deletes a batch Cloud Data Fusion pipeline.
 
         :param pipeline_name: Your pipeline name.
         :param version_id: Version of pipeline to delete
         :param instance_url: Endpoint on which the REST APIs is accessible for the instance.
-        :param namespace: f your pipeline belongs to a Basic edition instance, the namespace ID
+        :param namespace: if your pipeline belongs to a Basic edition instance, the namespace ID
             is always default. If your pipeline belongs to an Enterprise edition instance, you
             can create a namespace.
         """
@@ -360,9 +357,20 @@ class DataFusionHook(GoogleBaseHook):
             url = os.path.join(url, "versions", version_id)
 
         response = self._cdap_request(url=url, method="DELETE", body=None)
-        self._check_response_status_and_data(
-            response, f"Deleting a pipeline failed with code {response.status}"
-        )
+        # Check for 409 error: the previous step for starting/stopping pipeline could still be in progress.
+        # Waiting some time before retry.
+        for time_to_wait in exponential_sleep_generator(initial=10, maximum=120):
+            try:
+                self._check_response_status_and_data(
+                    response, f"Deleting a pipeline failed with code {response.status}: {response.data}"
+                )
+                break
+            except AirflowException as exc:
+                if "409" in str(exc):
+                    sleep(time_to_wait)
+                    response = self._cdap_request(url=url, method="DELETE", body=None)
+                else:
+                    raise
 
     def list_pipelines(
         self,
@@ -485,11 +493,19 @@ class DataFusionHook(GoogleBaseHook):
 
 
 class DataFusionAsyncHook(GoogleBaseAsyncHook):
-    """Class to get asynchronous hook for DataFusion"""
+    """Class to get asynchronous hook for DataFusion."""
 
     sync_hook_class = DataFusionHook
     scopes = ["https://www.googleapis.com/auth/cloud-platform"]
 
+    def __init__(self, **kwargs):
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
+            )
+        super().__init__(**kwargs)
+
     @staticmethod
     def _base_url(instance_url: str, namespace: str) -> str:
         return urljoin(f"{instance_url}/", f"v3/namespaces/{quote(namespace)}/apps/")
