@@ -19,6 +19,7 @@
 from __future__ import annotations
 
 import time
+from functools import cached_property
 from typing import TYPE_CHECKING, Sequence
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
@@ -31,7 +32,7 @@ from google.cloud.bigquery_datatransfer_v1 import (
 )
 
 from airflow import AirflowException
-from airflow.compat.functools import cached_property
+from airflow.configuration import conf
 from airflow.providers.google.cloud.hooks.bigquery_dts import BiqQueryDataTransferServiceHook, get_object_id
 from airflow.providers.google.cloud.links.bigquery_dts import BigQueryDataTransferConfigLink
 from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
@@ -218,10 +219,10 @@ class BigQueryDeleteDataTransferConfigOperator(GoogleCloudBaseOperator):
 
 class BigQueryDataTransferServiceStartTransferRunsOperator(GoogleCloudBaseOperator):
     """
-    Start manual transfer runs to be executed now with schedule_time equal
-    to current time. The transfer runs can be created for a time range where
-    the run_time is between start_time (inclusive) and end_time
-    (exclusive), or for a specific run_time.
+    Start manual transfer runs to be executed now with schedule_time equal to current time.
+
+    The transfer runs can be created for a time range where the run_time is between
+    start_time (inclusive) and end_time (exclusive), or for a specific run_time.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -279,7 +280,7 @@ class BigQueryDataTransferServiceStartTransferRunsOperator(GoogleCloudBaseOperat
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id="google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
-        deferrable: bool = False,
+        deferrable: bool = conf.getboolean("operators", "default_deferrable", fallback=False),
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -354,7 +355,7 @@ class BigQueryDataTransferServiceStartTransferRunsOperator(GoogleCloudBaseOperat
         )
 
     def _wait_for_transfer_to_be_done(self, run_id: str, transfer_config_id: str, interval: int = 10):
-        if interval < 0:
+        if interval <= 0:
             raise ValueError("Interval must be > 0")
 
         while True:
