@@ -14,9 +14,9 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""
-.. spelling::
+"""Spelling exceptions.
 
+.. spelling:word-list::
     CreateRunResponse
     DatasetResource
     LinkedServiceResource
@@ -36,6 +36,7 @@ from functools import wraps
 from typing import Any, Callable, TypeVar, Union, cast
 
 from asgiref.sync import sync_to_async
+from azure.core.exceptions import ServiceRequestError
 from azure.core.polling import LROPoller
 from azure.identity import ClientSecretCredential, DefaultAzureCredential
 from azure.identity.aio import (
@@ -157,7 +158,7 @@ class AzureDataFactoryHook(BaseHook):
 
     @staticmethod
     def get_connection_form_widgets() -> dict[str, Any]:
-        """Returns connection widgets to add to connection form"""
+        """Returns connection widgets to add to connection form."""
         from flask_appbuilder.fieldwidgets import BS3TextFieldWidget
         from flask_babel import lazy_gettext
         from wtforms import StringField
@@ -173,7 +174,7 @@ class AzureDataFactoryHook(BaseHook):
 
     @staticmethod
     def get_ui_field_behaviour() -> dict[str, Any]:
-        """Returns custom field behaviour"""
+        """Returns custom field behaviour."""
         return {
             "hidden_fields": ["schema", "port", "host", "extra"],
             "relabeling": {
@@ -214,6 +215,10 @@ class AzureDataFactoryHook(BaseHook):
 
         return self._conn
 
+    def refresh_conn(self) -> DataFactoryManagementClient:
+        self._conn = None
+        return self.get_conn()
+
     @provide_targeted_factory
     def get_factory(
         self, resource_group_name: str | None = None, factory_name: str | None = None, **config: Any
@@ -812,6 +817,7 @@ class AzureDataFactoryHook(BaseHook):
             resource_group_name=resource_group_name,
         )
         pipeline_run_status = self.get_pipeline_run_status(**pipeline_run_info)
+        executed_after_token_refresh = True
 
         start_time = time.monotonic()
 
@@ -828,7 +834,14 @@ class AzureDataFactoryHook(BaseHook):
             # Wait to check the status of the pipeline run based on the ``check_interval`` configured.
             time.sleep(check_interval)
 
-            pipeline_run_status = self.get_pipeline_run_status(**pipeline_run_info)
+            try:
+                pipeline_run_status = self.get_pipeline_run_status(**pipeline_run_info)
+                executed_after_token_refresh = True
+            except ServiceRequestError:
+                if executed_after_token_refresh:
+                    self.refresh_conn()
+                    continue
+                raise
 
         return pipeline_run_status in expected_statuses
 
@@ -1088,7 +1101,7 @@ def provide_targeted_factory_async(func: T) -> T:
 
 class AzureDataFactoryAsyncHook(AzureDataFactoryHook):
     """
-    An Async Hook that connects to Azure DataFactory to perform pipeline operations
+    An Async Hook that connects to Azure DataFactory to perform pipeline operations.
 
     :param azure_data_factory_conn_id: The :ref:`Azure Data Factory connection id<howto/connection:adf>`.
     """
@@ -1101,7 +1114,7 @@ class AzureDataFactoryAsyncHook(AzureDataFactoryHook):
         super().__init__(azure_data_factory_conn_id=azure_data_factory_conn_id)
 
     async def get_async_conn(self) -> AsyncDataFactoryManagementClient:
-        """Get async connection and connect to azure data factory"""
+        """Get async connection and connect to azure data factory."""
         if self._async_conn is not None:
             return self._async_conn
 
@@ -1132,6 +1145,10 @@ class AzureDataFactoryAsyncHook(AzureDataFactoryHook):
 
         return self._async_conn
 
+    async def refresh_conn(self) -> AsyncDataFactoryManagementClient:
+        self._conn = None
+        return await self.get_async_conn()
+
     @provide_targeted_factory_async
     async def get_pipeline_run(
         self,
@@ -1141,7 +1158,45 @@ class AzureDataFactoryAsyncHook(AzureDataFactoryHook):
         **config: Any,
     ) -> PipelineRun:
         """
-        Connect to Azure Data Factory asynchronously to get the pipeline run details by run id
+        Connect to Azure Data Factory asynchronously to get the pipeline run details by run id.
+
+        :param run_id: The pipeline run identifier.
+        :param resource_group_name: The resource group name.
+        :param factory_name: The factory name.
+        :param config: Extra parameters for the ADF client.
+        """
+        client = await self.get_async_conn()
+        pipeline_run = await client.pipeline_runs.get(resource_group_name, factory_name, run_id)
+        return pipeline_run
+
+    async def get_adf_pipeline_run_status(
+        self, run_id: str, resource_group_name: str | None = None, factory_name: str | None = None
+    ) -> str:
+        """
+        Connect to Azure Data Factory asynchronously and get the pipeline status by run_id.
+
+        :param run_id: The pipeline run identifier.
+        :param resource_group_name: The resource group name.
+        :param factory_name: The factory name.
+        """
+        pipeline_run = await self.get_pipeline_run(
+            run_id=run_id,
+            factory_name=factory_name,
+            resource_group_name=resource_group_name,
+        )
+        status: str = pipeline_run.status
+        return status
+
+    @provide_targeted_factory_async
+    async def cancel_pipeline_run(
+        self,
+        run_id: str,
+        resource_group_name: str | None = None,
+        factory_name: str | None = None,
+        **config: Any,
+    ) -> None:
+        """
+        Cancel the pipeline run.
 
         :param run_id: The pipeline run identifier.
         :param resource_group_name: The resource group name.
@@ -1150,28 +1205,6 @@ class AzureDataFactoryAsyncHook(AzureDataFactoryHook):
         """
         client = await self.get_async_conn()
         try:
-            pipeline_run = await client.pipeline_runs.get(resource_group_name, factory_name, run_id)
-            return pipeline_run
-        except Exception as e:
-            raise AirflowException(e)
-
-    async def get_adf_pipeline_run_status(
-        self, run_id: str, resource_group_name: str | None = None, factory_name: str | None = None
-    ) -> str:
-        """
-        Connect to Azure Data Factory asynchronously and get the pipeline status by run_id
-
-        :param run_id: The pipeline run identifier.
-        :param resource_group_name: The resource group name.
-        :param factory_name: The factory name.
-        """
-        try:
-            pipeline_run = await self.get_pipeline_run(
-                run_id=run_id,
-                factory_name=factory_name,
-                resource_group_name=resource_group_name,
-            )
-            status: str = pipeline_run.status
-            return status
+            await client.pipeline_runs.cancel(resource_group_name, factory_name, run_id)
         except Exception as e:
             raise AirflowException(e)
