@@ -14,123 +14,127 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
-from typing import Dict, Iterable, Optional, Union
+import warnings
+from dataclasses import dataclass
+from typing import TYPE_CHECKING, Iterable, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.yandex.hooks.yandexcloud_dataproc import DataprocHook
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
+
+@dataclass
+class InitializationAction:
+    """Data for initialization action to be run at start of DataProc cluster."""
+
+    uri: str  # Uri of the executable file
+    args: Sequence[str]  # Arguments to the initialization action
+    timeout: int  # Execution timeout
+
 
 class DataprocCreateClusterOperator(BaseOperator):
     """Creates Yandex.Cloud Data Proc cluster.
 
     :param folder_id: ID of the folder in which cluster should be created.
-    :type folder_id: Optional[str]
     :param cluster_name: Cluster name. Must be unique inside the folder.
-    :type cluster_name: Optional[str]
     :param cluster_description: Cluster description.
-    :type cluster_description: str
     :param cluster_image_version: Cluster image version. Use default.
-    :type cluster_image_version: str
     :param ssh_public_keys: List of SSH public keys that will be deployed to created compute instances.
-    :type ssh_public_keys: Optional[Union[str, Iterable[str]]]
     :param subnet_id: ID of the subnetwork. All Data Proc cluster nodes will use one subnetwork.
-    :type subnet_id: str
     :param services: List of services that will be installed to the cluster. Possible options:
         HDFS, YARN, MAPREDUCE, HIVE, TEZ, ZOOKEEPER, HBASE, SQOOP, FLUME, SPARK, SPARK, ZEPPELIN, OOZIE
-    :type services: Iterable[str]
     :param s3_bucket: Yandex.Cloud S3 bucket to store cluster logs.
                       Jobs will not work if the bucket is not specified.
-    :type s3_bucket: Optional[str]
     :param zone: Availability zone to create cluster in.
                  Currently there are ru-central1-a, ru-central1-b and ru-central1-c.
-    :type zone: str
     :param service_account_id: Service account id for the cluster.
                                Service account can be created inside the folder.
-    :type service_account_id: Optional[str]
     :param masternode_resource_preset: Resources preset (CPU+RAM configuration)
                                        for the primary node of the cluster.
-    :type masternode_resource_preset: str
     :param masternode_disk_size: Masternode storage size in GiB.
-    :type masternode_disk_size: int
     :param masternode_disk_type: Masternode storage type. Possible options: network-ssd, network-hdd.
-    :type masternode_disk_type: str
     :param datanode_resource_preset: Resources preset (CPU+RAM configuration)
                                      for the data nodes of the cluster.
-    :type datanode_resource_preset: str
     :param datanode_disk_size: Datanodes storage size in GiB.
-    :type datanode_disk_size: int
     :param datanode_disk_type: Datanodes storage type. Possible options: network-ssd, network-hdd.
-    :type datanode_disk_type: str
     :param computenode_resource_preset: Resources preset (CPU+RAM configuration)
                                         for the compute nodes of the cluster.
-    :type computenode_resource_preset: str
     :param computenode_disk_size: Computenodes storage size in GiB.
-    :type computenode_disk_size: int
     :param computenode_disk_type: Computenodes storage type. Possible options: network-ssd, network-hdd.
-    :type computenode_disk_type: str
     :param connection_id: ID of the Yandex.Cloud Airflow connection.
-    :type connection_id: Optional[str]
-    :type computenode_max_count: int
     :param computenode_max_count: Maximum number of nodes of compute autoscaling subcluster.
     :param computenode_warmup_duration: The warmup time of the instance in seconds. During this time,
                                         traffic is sent to the instance,
                                         but instance metrics are not collected. In seconds.
-    :type computenode_warmup_duration: int
     :param computenode_stabilization_duration: Minimum amount of time in seconds for monitoring before
                                    Instance Groups can reduce the number of instances in the group.
                                    During this time, the group size doesn't decrease,
                                    even if the new metric values indicate that it should. In seconds.
-    :type computenode_stabilization_duration: int
     :param computenode_preemptible: Preemptible instances are stopped at least once every 24 hours,
                         and can be stopped at any time if their resources are needed by Compute.
-    :type computenode_preemptible: bool
     :param computenode_cpu_utilization_target: Defines an autoscaling rule
                                    based on the average CPU utilization of the instance group.
                                    in percents. 10-100.
                                    By default is not set and default autoscaling strategy is used.
-    :type computenode_cpu_utilization_target: int
     :param computenode_decommission_timeout: Timeout to gracefully decommission nodes during downscaling.
-                                             In seconds.
-    :type computenode_decommission_timeout: int
+                                             In seconds
+    :param properties: Properties passed to main node software.
+                        Docs: https://cloud.yandex.com/docs/data-proc/concepts/settings-list
+    :param enable_ui_proxy: Enable UI Proxy feature for forwarding Hadoop components web interfaces
+                        Docs: https://cloud.yandex.com/docs/data-proc/concepts/ui-proxy
+    :param host_group_ids: Dedicated host groups to place VMs of cluster on.
+                        Docs: https://cloud.yandex.com/docs/compute/concepts/dedicated-host
+    :param security_group_ids: User security groups.
+                        Docs: https://cloud.yandex.com/docs/data-proc/concepts/network#security-groups
     :param log_group_id: Id of log group to write logs. By default logs will be sent to default log group.
                     To disable cloud log sending set cluster property dataproc:disable_cloud_logging = true
-    :type log_group_id: str
+                    Docs: https://cloud.yandex.com/docs/data-proc/concepts/logs
+    :param initialization_actions: Set of init-actions to run when cluster starts.
+                        Docs: https://cloud.yandex.com/docs/data-proc/concepts/init-action
     """
 
     def __init__(
         self,
         *,
-        folder_id: Optional[str] = None,
-        cluster_name: Optional[str] = None,
-        cluster_description: Optional[str] = '',
-        cluster_image_version: Optional[str] = None,
-        ssh_public_keys: Optional[Union[str, Iterable[str]]] = None,
-        subnet_id: Optional[str] = None,
-        services: Iterable[str] = ('HDFS', 'YARN', 'MAPREDUCE', 'HIVE', 'SPARK'),
-        s3_bucket: Optional[str] = None,
-        zone: str = 'ru-central1-b',
-        service_account_id: Optional[str] = None,
-        masternode_resource_preset: Optional[str] = None,
-        masternode_disk_size: Optional[int] = None,
-        masternode_disk_type: Optional[str] = None,
-        datanode_resource_preset: Optional[str] = None,
-        datanode_disk_size: Optional[int] = None,
-        datanode_disk_type: Optional[str] = None,
+        folder_id: str | None = None,
+        cluster_name: str | None = None,
+        cluster_description: str | None = "",
+        cluster_image_version: str | None = None,
+        ssh_public_keys: str | Iterable[str] | None = None,
+        subnet_id: str | None = None,
+        services: Iterable[str] = ("HDFS", "YARN", "MAPREDUCE", "HIVE", "SPARK"),
+        s3_bucket: str | None = None,
+        zone: str = "ru-central1-b",
+        service_account_id: str | None = None,
+        masternode_resource_preset: str | None = None,
+        masternode_disk_size: int | None = None,
+        masternode_disk_type: str | None = None,
+        datanode_resource_preset: str | None = None,
+        datanode_disk_size: int | None = None,
+        datanode_disk_type: str | None = None,
         datanode_count: int = 1,
-        computenode_resource_preset: Optional[str] = None,
-        computenode_disk_size: Optional[int] = None,
-        computenode_disk_type: Optional[str] = None,
+        computenode_resource_preset: str | None = None,
+        computenode_disk_size: int | None = None,
+        computenode_disk_type: str | None = None,
         computenode_count: int = 0,
-        computenode_max_hosts_count: Optional[int] = None,
-        computenode_measurement_duration: Optional[int] = None,
-        computenode_warmup_duration: Optional[int] = None,
-        computenode_stabilization_duration: Optional[int] = None,
+        computenode_max_hosts_count: int | None = None,
+        computenode_measurement_duration: int | None = None,
+        computenode_warmup_duration: int | None = None,
+        computenode_stabilization_duration: int | None = None,
         computenode_preemptible: bool = False,
-        computenode_cpu_utilization_target: Optional[int] = None,
-        computenode_decommission_timeout: Optional[int] = None,
-        connection_id: Optional[str] = None,
-        log_group_id: Optional[str] = None,
+        computenode_cpu_utilization_target: int | None = None,
+        computenode_decommission_timeout: int | None = None,
+        connection_id: str | None = None,
+        properties: dict[str, str] | None = None,
+        enable_ui_proxy: bool = False,
+        host_group_ids: Iterable[str] | None = None,
+        security_group_ids: Iterable[str] | None = None,
+        log_group_id: str | None = None,
+        initialization_actions: Iterable[InitializationAction] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -163,11 +167,16 @@ class DataprocCreateClusterOperator(BaseOperator):
         self.computenode_preemptible = computenode_preemptible
         self.computenode_cpu_utilization_target = computenode_cpu_utilization_target
         self.computenode_decommission_timeout = computenode_decommission_timeout
+        self.properties = properties
+        self.enable_ui_proxy = enable_ui_proxy
+        self.host_group_ids = host_group_ids
+        self.security_group_ids = security_group_ids
         self.log_group_id = log_group_id
+        self.initialization_actions = initialization_actions
 
-        self.hook: Optional[DataprocHook] = None
+        self.hook: DataprocHook | None = None
 
-    def execute(self, context) -> None:
+    def execute(self, context: Context) -> dict:
         self.hook = DataprocHook(
             yandex_conn_id=self.yandex_conn_id,
         )
@@ -200,154 +209,158 @@ class DataprocCreateClusterOperator(BaseOperator):
             computenode_preemptible=self.computenode_preemptible,
             computenode_cpu_utilization_target=self.computenode_cpu_utilization_target,
             computenode_decommission_timeout=self.computenode_decommission_timeout,
+            properties=self.properties,
+            enable_ui_proxy=self.enable_ui_proxy,
+            host_group_ids=self.host_group_ids,
+            security_group_ids=self.security_group_ids,
             log_group_id=self.log_group_id,
+            initialization_actions=self.initialization_actions
+            and [
+                self.hook.sdk.wrappers.InitializationAction(
+                    uri=init_action.uri,
+                    args=init_action.args,
+                    timeout=init_action.timeout,
+                )
+                for init_action in self.initialization_actions
+            ],
         )
-        context['task_instance'].xcom_push(key='cluster_id', value=operation_result.response.id)
-        context['task_instance'].xcom_push(key='yandexcloud_connection_id', value=self.yandex_conn_id)
+        cluster_id = operation_result.response.id
+
+        context["task_instance"].xcom_push(key="cluster_id", value=cluster_id)
+        # Deprecated
+        context["task_instance"].xcom_push(key="yandexcloud_connection_id", value=self.yandex_conn_id)
+        return cluster_id
+
+    @property
+    def cluster_id(self):
+        return self.output
 
 
-class DataprocDeleteClusterOperator(BaseOperator):
+class DataprocBaseOperator(BaseOperator):
+    """Base class for DataProc operators working with given cluster.
+
+    :param connection_id: ID of the Yandex.Cloud Airflow connection.
+    :param cluster_id: ID of the cluster to remove. (templated)
+    """
+
+    template_fields: Sequence[str] = ("cluster_id",)
+
+    def __init__(self, *, yandex_conn_id: str | None = None, cluster_id: str | None = None, **kwargs) -> None:
+        super().__init__(**kwargs)
+        self.cluster_id = cluster_id
+        self.yandex_conn_id = yandex_conn_id
+
+    def _setup(self, context: Context) -> DataprocHook:
+        if self.cluster_id is None:
+            self.cluster_id = context["task_instance"].xcom_pull(key="cluster_id")
+        if self.yandex_conn_id is None:
+            xcom_yandex_conn_id = context["task_instance"].xcom_pull(key="yandexcloud_connection_id")
+            if xcom_yandex_conn_id:
+                warnings.warn("Implicit pass of `yandex_conn_id` is deprecated, please pass it explicitly")
+                self.yandex_conn_id = xcom_yandex_conn_id
+
+        return DataprocHook(yandex_conn_id=self.yandex_conn_id)
+
+    def execute(self, context: Context):
+        raise NotImplementedError()
+
+
+class DataprocDeleteClusterOperator(DataprocBaseOperator):
     """Deletes Yandex.Cloud Data Proc cluster.
 
     :param connection_id: ID of the Yandex.Cloud Airflow connection.
-    :type connection_id: Optional[str]
     :param cluster_id: ID of the cluster to remove. (templated)
-    :type cluster_id: Optional[str]
     """
 
-    template_fields = ['cluster_id']
+    def __init__(self, *, connection_id: str | None = None, cluster_id: str | None = None, **kwargs) -> None:
+        super().__init__(yandex_conn_id=connection_id, cluster_id=cluster_id, **kwargs)
 
-    def __init__(
-        self, *, connection_id: Optional[str] = None, cluster_id: Optional[str] = None, **kwargs
-    ) -> None:
-        super().__init__(**kwargs)
-        self.yandex_conn_id = connection_id
-        self.cluster_id = cluster_id
-        self.hook: Optional[DataprocHook] = None
-
-    def execute(self, context) -> None:
-        cluster_id = self.cluster_id or context['task_instance'].xcom_pull(key='cluster_id')
-        yandex_conn_id = self.yandex_conn_id or context['task_instance'].xcom_pull(
-            key='yandexcloud_connection_id'
-        )
-        self.hook = DataprocHook(
-            yandex_conn_id=yandex_conn_id,
-        )
-        self.hook.client.delete_cluster(cluster_id)
+    def execute(self, context: Context) -> None:
+        hook = self._setup(context)
+        hook.client.delete_cluster(self.cluster_id)
 
 
-class DataprocCreateHiveJobOperator(BaseOperator):
+class DataprocCreateHiveJobOperator(DataprocBaseOperator):
     """Runs Hive job in Data Proc cluster.
 
     :param query: Hive query.
-    :type query: Optional[str]
     :param query_file_uri: URI of the script that contains Hive queries. Can be placed in HDFS or S3.
-    :type query_file_uri: Optional[str]
     :param properties: A mapping of property names to values, used to configure Hive.
-    :type properties: Optional[Dist[str, str]]
     :param script_variables: Mapping of query variable names to values.
-    :type script_variables: Optional[Dist[str, str]]
     :param continue_on_failure: Whether to continue executing queries if a query fails.
-    :type continue_on_failure: bool
     :param name: Name of the job. Used for labeling.
-    :type name: str
     :param cluster_id: ID of the cluster to run job in.
-                       Will try to take the ID from Dataproc Hook object if ot specified. (templated)
-    :type cluster_id: Optional[str]
+                       Will try to take the ID from Dataproc Hook object if it's specified. (templated)
     :param connection_id: ID of the Yandex.Cloud Airflow connection.
-    :type connection_id: Optional[str]
     """
 
-    template_fields = ['cluster_id']
-
     def __init__(
         self,
         *,
-        query: Optional[str] = None,
-        query_file_uri: Optional[str] = None,
-        script_variables: Optional[Dict[str, str]] = None,
+        query: str | None = None,
+        query_file_uri: str | None = None,
+        script_variables: dict[str, str] | None = None,
         continue_on_failure: bool = False,
-        properties: Optional[Dict[str, str]] = None,
-        name: str = 'Hive job',
-        cluster_id: Optional[str] = None,
-        connection_id: Optional[str] = None,
+        properties: dict[str, str] | None = None,
+        name: str = "Hive job",
+        cluster_id: str | None = None,
+        connection_id: str | None = None,
         **kwargs,
     ) -> None:
-        super().__init__(**kwargs)
+        super().__init__(yandex_conn_id=connection_id, cluster_id=cluster_id, **kwargs)
         self.query = query
         self.query_file_uri = query_file_uri
         self.script_variables = script_variables
         self.continue_on_failure = continue_on_failure
         self.properties = properties
         self.name = name
-        self.cluster_id = cluster_id
-        self.connection_id = connection_id
-        self.hook: Optional[DataprocHook] = None
 
-    def execute(self, context) -> None:
-        cluster_id = self.cluster_id or context['task_instance'].xcom_pull(key='cluster_id')
-        yandex_conn_id = self.connection_id or context['task_instance'].xcom_pull(
-            key='yandexcloud_connection_id'
-        )
-        self.hook = DataprocHook(
-            yandex_conn_id=yandex_conn_id,
-        )
-        self.hook.client.create_hive_job(
+    def execute(self, context: Context) -> None:
+        hook = self._setup(context)
+        hook.client.create_hive_job(
             query=self.query,
             query_file_uri=self.query_file_uri,
             script_variables=self.script_variables,
             continue_on_failure=self.continue_on_failure,
             properties=self.properties,
             name=self.name,
-            cluster_id=cluster_id,
+            cluster_id=self.cluster_id,
         )
 
 
-class DataprocCreateMapReduceJobOperator(BaseOperator):
+class DataprocCreateMapReduceJobOperator(DataprocBaseOperator):
     """Runs Mapreduce job in Data Proc cluster.
 
     :param main_jar_file_uri: URI of jar file with job.
                               Can be placed in HDFS or S3. Can be specified instead of main_class.
-    :type main_jar_file_uri: Optional[str]
     :param main_class: Name of the main class of the job. Can be specified instead of main_jar_file_uri.
-    :type main_class: Optional[str]
     :param file_uris: URIs of files used in the job. Can be placed in HDFS or S3.
-    :type file_uris: Optional[Iterable[str]]
     :param archive_uris: URIs of archive files used in the job. Can be placed in HDFS or S3.
-    :type archive_uris: Optional[Iterable[str]]
     :param jar_file_uris: URIs of JAR files used in the job. Can be placed in HDFS or S3.
-    :type jar_file_uris: Optional[Iterable[str]]
     :param properties: Properties for the job.
-    :type properties: Optional[Dist[str, str]]
     :param args: Arguments to be passed to the job.
-    :type args: Optional[Iterable[str]]
     :param name: Name of the job. Used for labeling.
-    :type name: str
     :param cluster_id: ID of the cluster to run job in.
-                       Will try to take the ID from Dataproc Hook object if ot specified. (templated)
-    :type cluster_id: Optional[str]
+                       Will try to take the ID from Dataproc Hook object if it's specified. (templated)
     :param connection_id: ID of the Yandex.Cloud Airflow connection.
-    :type connection_id: Optional[str]
     """
 
-    template_fields = ['cluster_id']
-
     def __init__(
         self,
         *,
-        main_class: Optional[str] = None,
-        main_jar_file_uri: Optional[str] = None,
-        jar_file_uris: Optional[Iterable[str]] = None,
-        archive_uris: Optional[Iterable[str]] = None,
-        file_uris: Optional[Iterable[str]] = None,
-        args: Optional[Iterable[str]] = None,
-        properties: Optional[Dict[str, str]] = None,
-        name: str = 'Mapreduce job',
-        cluster_id: Optional[str] = None,
-        connection_id: Optional[str] = None,
+        main_class: str | None = None,
+        main_jar_file_uri: str | None = None,
+        jar_file_uris: Iterable[str] | None = None,
+        archive_uris: Iterable[str] | None = None,
+        file_uris: Iterable[str] | None = None,
+        args: Iterable[str] | None = None,
+        properties: dict[str, str] | None = None,
+        name: str = "Mapreduce job",
+        cluster_id: str | None = None,
+        connection_id: str | None = None,
         **kwargs,
     ) -> None:
-        super().__init__(**kwargs)
+        super().__init__(yandex_conn_id=connection_id, cluster_id=cluster_id, **kwargs)
         self.main_class = main_class
         self.main_jar_file_uri = main_jar_file_uri
         self.jar_file_uris = jar_file_uris
@@ -356,19 +369,10 @@ class DataprocCreateMapReduceJobOperator(BaseOperator):
         self.args = args
         self.properties = properties
         self.name = name
-        self.cluster_id = cluster_id
-        self.connection_id = connection_id
-        self.hook: Optional[DataprocHook] = None
 
-    def execute(self, context) -> None:
-        cluster_id = self.cluster_id or context['task_instance'].xcom_pull(key='cluster_id')
-        yandex_conn_id = self.connection_id or context['task_instance'].xcom_pull(
-            key='yandexcloud_connection_id'
-        )
-        self.hook = DataprocHook(
-            yandex_conn_id=yandex_conn_id,
-        )
-        self.hook.client.create_mapreduce_job(
+    def execute(self, context: Context) -> None:
+        hook = self._setup(context)
+        hook.client.create_mapreduce_job(
             main_class=self.main_class,
             main_jar_file_uri=self.main_jar_file_uri,
             jar_file_uris=self.jar_file_uris,
@@ -377,65 +381,50 @@ class DataprocCreateMapReduceJobOperator(BaseOperator):
             args=self.args,
             properties=self.properties,
             name=self.name,
-            cluster_id=cluster_id,
+            cluster_id=self.cluster_id,
         )
 
 
-class DataprocCreateSparkJobOperator(BaseOperator):
+class DataprocCreateSparkJobOperator(DataprocBaseOperator):
     """Runs Spark job in Data Proc cluster.
 
     :param main_jar_file_uri: URI of jar file with job. Can be placed in HDFS or S3.
-    :type main_jar_file_uri: Optional[str]
     :param main_class: Name of the main class of the job.
-    :type main_class: Optional[str]
     :param file_uris: URIs of files used in the job. Can be placed in HDFS or S3.
-    :type file_uris: Optional[Iterable[str]]
     :param archive_uris: URIs of archive files used in the job. Can be placed in HDFS or S3.
-    :type archive_uris: Optional[Iterable[str]]
     :param jar_file_uris: URIs of JAR files used in the job. Can be placed in HDFS or S3.
-    :type jar_file_uris: Optional[Iterable[str]]
     :param properties: Properties for the job.
-    :type properties: Optional[Dist[str, str]]
     :param args: Arguments to be passed to the job.
-    :type args: Optional[Iterable[str]]
     :param name: Name of the job. Used for labeling.
-    :type name: str
     :param cluster_id: ID of the cluster to run job in.
-                       Will try to take the ID from Dataproc Hook object if ot specified. (templated)
-    :type cluster_id: Optional[str]
+                       Will try to take the ID from Dataproc Hook object if it's specified. (templated)
     :param connection_id: ID of the Yandex.Cloud Airflow connection.
-    :type connection_id: Optional[str]
     :param packages: List of maven coordinates of jars to include on the driver and executor classpaths.
-    :type packages: Optional[Iterable[str]]
     :param repositories: List of additional remote repositories to search for the maven coordinates
                         given with --packages.
-    :type repositories: Optional[Iterable[str]]
     :param exclude_packages: List of groupId:artifactId, to exclude while resolving the dependencies
                         provided in --packages to avoid dependency conflicts.
-    :type exclude_packages: Optional[Iterable[str]]
     """
 
-    template_fields = ['cluster_id']
-
     def __init__(
         self,
         *,
-        main_class: Optional[str] = None,
-        main_jar_file_uri: Optional[str] = None,
-        jar_file_uris: Optional[Iterable[str]] = None,
-        archive_uris: Optional[Iterable[str]] = None,
-        file_uris: Optional[Iterable[str]] = None,
-        args: Optional[Iterable[str]] = None,
-        properties: Optional[Dict[str, str]] = None,
-        name: str = 'Spark job',
-        cluster_id: Optional[str] = None,
-        connection_id: Optional[str] = None,
-        packages: Optional[Iterable[str]] = None,
-        repositories: Optional[Iterable[str]] = None,
-        exclude_packages: Optional[Iterable[str]] = None,
+        main_class: str | None = None,
+        main_jar_file_uri: str | None = None,
+        jar_file_uris: Iterable[str] | None = None,
+        archive_uris: Iterable[str] | None = None,
+        file_uris: Iterable[str] | None = None,
+        args: Iterable[str] | None = None,
+        properties: dict[str, str] | None = None,
+        name: str = "Spark job",
+        cluster_id: str | None = None,
+        connection_id: str | None = None,
+        packages: Iterable[str] | None = None,
+        repositories: Iterable[str] | None = None,
+        exclude_packages: Iterable[str] | None = None,
         **kwargs,
     ) -> None:
-        super().__init__(**kwargs)
+        super().__init__(yandex_conn_id=connection_id, cluster_id=cluster_id, **kwargs)
         self.main_class = main_class
         self.main_jar_file_uri = main_jar_file_uri
         self.jar_file_uris = jar_file_uris
@@ -444,22 +433,13 @@ class DataprocCreateSparkJobOperator(BaseOperator):
         self.args = args
         self.properties = properties
         self.name = name
-        self.cluster_id = cluster_id
-        self.connection_id = connection_id
         self.packages = packages
         self.repositories = repositories
         self.exclude_packages = exclude_packages
-        self.hook: Optional[DataprocHook] = None
 
-    def execute(self, context) -> None:
-        cluster_id = self.cluster_id or context['task_instance'].xcom_pull(key='cluster_id')
-        yandex_conn_id = self.connection_id or context['task_instance'].xcom_pull(
-            key='yandexcloud_connection_id'
-        )
-        self.hook = DataprocHook(
-            yandex_conn_id=yandex_conn_id,
-        )
-        self.hook.client.create_spark_job(
+    def execute(self, context: Context) -> None:
+        hook = self._setup(context)
+        hook.client.create_spark_job(
             main_class=self.main_class,
             main_jar_file_uri=self.main_jar_file_uri,
             jar_file_uris=self.jar_file_uris,
@@ -471,65 +451,50 @@ class DataprocCreateSparkJobOperator(BaseOperator):
             repositories=self.repositories,
             exclude_packages=self.exclude_packages,
             name=self.name,
-            cluster_id=cluster_id,
+            cluster_id=self.cluster_id,
         )
 
 
-class DataprocCreatePysparkJobOperator(BaseOperator):
+class DataprocCreatePysparkJobOperator(DataprocBaseOperator):
     """Runs Pyspark job in Data Proc cluster.
 
     :param main_python_file_uri: URI of python file with job. Can be placed in HDFS or S3.
-    :type main_python_file_uri: Optional[str]
     :param python_file_uris: URIs of python files used in the job. Can be placed in HDFS or S3.
-    :type python_file_uris: Optional[Iterable[str]]
     :param file_uris: URIs of files used in the job. Can be placed in HDFS or S3.
-    :type file_uris: Optional[Iterable[str]]
     :param archive_uris: URIs of archive files used in the job. Can be placed in HDFS or S3.
-    :type archive_uris: Optional[Iterable[str]]
     :param jar_file_uris: URIs of JAR files used in the job. Can be placed in HDFS or S3.
-    :type jar_file_uris: Optional[Iterable[str]]
     :param properties: Properties for the job.
-    :type properties: Optional[Dist[str, str]]
     :param args: Arguments to be passed to the job.
-    :type args: Optional[Iterable[str]]
     :param name: Name of the job. Used for labeling.
-    :type name: str
     :param cluster_id: ID of the cluster to run job in.
-                       Will try to take the ID from Dataproc Hook object if ot specified. (templated)
-    :type cluster_id: Optional[str]
+                       Will try to take the ID from Dataproc Hook object if it's specified. (templated)
     :param connection_id: ID of the Yandex.Cloud Airflow connection.
-    :type connection_id: Optional[str]
     :param packages: List of maven coordinates of jars to include on the driver and executor classpaths.
-    :type packages: Optional[Iterable[str]]
     :param repositories: List of additional remote repositories to search for the maven coordinates
                          given with --packages.
-    :type repositories: Optional[Iterable[str]]
     :param exclude_packages: List of groupId:artifactId, to exclude while resolving the dependencies
                          provided in --packages to avoid dependency conflicts.
-    :type exclude_packages: Optional[Iterable[str]]
     """
 
-    template_fields = ['cluster_id']
-
     def __init__(
         self,
         *,
-        main_python_file_uri: Optional[str] = None,
-        python_file_uris: Optional[Iterable[str]] = None,
-        jar_file_uris: Optional[Iterable[str]] = None,
-        archive_uris: Optional[Iterable[str]] = None,
-        file_uris: Optional[Iterable[str]] = None,
-        args: Optional[Iterable[str]] = None,
-        properties: Optional[Dict[str, str]] = None,
-        name: str = 'Pyspark job',
-        cluster_id: Optional[str] = None,
-        connection_id: Optional[str] = None,
-        packages: Optional[Iterable[str]] = None,
-        repositories: Optional[Iterable[str]] = None,
-        exclude_packages: Optional[Iterable[str]] = None,
+        main_python_file_uri: str | None = None,
+        python_file_uris: Iterable[str] | None = None,
+        jar_file_uris: Iterable[str] | None = None,
+        archive_uris: Iterable[str] | None = None,
+        file_uris: Iterable[str] | None = None,
+        args: Iterable[str] | None = None,
+        properties: dict[str, str] | None = None,
+        name: str = "Pyspark job",
+        cluster_id: str | None = None,
+        connection_id: str | None = None,
+        packages: Iterable[str] | None = None,
+        repositories: Iterable[str] | None = None,
+        exclude_packages: Iterable[str] | None = None,
         **kwargs,
     ) -> None:
-        super().__init__(**kwargs)
+        super().__init__(yandex_conn_id=connection_id, cluster_id=cluster_id, **kwargs)
         self.main_python_file_uri = main_python_file_uri
         self.python_file_uris = python_file_uris
         self.jar_file_uris = jar_file_uris
@@ -538,22 +503,13 @@ class DataprocCreatePysparkJobOperator(BaseOperator):
         self.args = args
         self.properties = properties
         self.name = name
-        self.cluster_id = cluster_id
-        self.connection_id = connection_id
         self.packages = packages
         self.repositories = repositories
         self.exclude_packages = exclude_packages
-        self.hook: Optional[DataprocHook] = None
 
-    def execute(self, context) -> None:
-        cluster_id = self.cluster_id or context['task_instance'].xcom_pull(key='cluster_id')
-        yandex_conn_id = self.connection_id or context['task_instance'].xcom_pull(
-            key='yandexcloud_connection_id'
-        )
-        self.hook = DataprocHook(
-            yandex_conn_id=yandex_conn_id,
-        )
-        self.hook.client.create_pyspark_job(
+    def execute(self, context: Context) -> None:
+        hook = self._setup(context)
+        hook.client.create_pyspark_job(
             main_python_file_uri=self.main_python_file_uri,
             python_file_uris=self.python_file_uris,
             jar_file_uris=self.jar_file_uris,
@@ -565,5 +521,5 @@ class DataprocCreatePysparkJobOperator(BaseOperator):
             repositories=self.repositories,
             exclude_packages=self.exclude_packages,
             name=self.name,
-            cluster_id=cluster_id,
+            cluster_id=self.cluster_id,
         )
