@@ -28,17 +28,13 @@ __all__ = [
 ]
 
 import sys
-
-if sys.version_info >= (3, 8):
-    from typing import Protocol, TypedDict, runtime_checkable
-else:
-    from typing_extensions import Protocol, TypedDict, runtime_checkable
+from typing import Protocol, TypedDict, runtime_checkable
 
 # Literal in 3.8 is limited to one single argument, not e.g. "Literal[1, 2]".
 if sys.version_info >= (3, 9):
     from typing import Literal
 else:
-    from typing_extensions import Literal
+    from typing import Literal
 
 if sys.version_info >= (3, 10):
     from typing import ParamSpec, TypeGuard
